@@ -30,9 +30,9 @@
 #include <bonobo/bonobo-ui-util.h>
 #include <eel/eel-debug.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
-#include <eel/eel-gtk-macros.h>
 #include <gtk/gtkclist.h>
 #include <gtk/gtkscrolledwindow.h>
+#include <libgnome/gnome-macros.h>
 #include <libnautilus-private/nautilus-bookmark.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus/nautilus-view-standard-main.h>
@@ -62,14 +62,10 @@ typedef struct {
 #define HISTORY_VIEW_COLUMN_NAME	1
 #define HISTORY_VIEW_COLUMN_COUNT	2
 
-static GtkType nautilus_history_view_get_type         (void);
-static void    nautilus_history_view_initialize_class (NautilusHistoryViewClass *klass);
-static void    nautilus_history_view_initialize       (NautilusHistoryView      *view);
-static void    nautilus_history_view_destroy          (GtkObject                *object);
+static GtkType nautilus_history_view_get_type   (void);
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusHistoryView,
-				   nautilus_history_view,
-				   NAUTILUS_TYPE_VIEW)
+BONOBO_CLASS_BOILERPLATE (NautilusHistoryView, nautilus_history_view,
+			  NautilusView, NAUTILUS_TYPE_VIEW)
 
 static NautilusBookmark *
 get_bookmark_from_row (GtkCList *list, int row)
@@ -110,8 +106,8 @@ install_icon (GtkCList *list, int row, GdkPixbuf *pixbuf)
 }
 
 static void
-update_history (NautilusHistoryView *view,
-		Nautilus_History *history)
+update_history (NautilusHistoryView    *view,
+		const Nautilus_History *history)
 {
 	char *cols[HISTORY_VIEW_COLUMN_COUNT];
 	int new_row;
@@ -129,10 +125,6 @@ update_history (NautilusHistoryView *view,
 
 	list = view->list;
 
-	if (GTK_OBJECT_DESTROYED (list)) {
-		return;
-	}
-
 	/* Set up a local boolean so we can detect that the view has
 	 * been destroyed. We can't ask the view itself because once
 	 * it's destroyed it's pointer is a pointer to freed storage.
@@ -173,12 +165,12 @@ update_history (NautilusHistoryView *view,
 		new_row = gtk_clist_append (list, cols);
 		
 		gtk_clist_set_row_data_full (list, new_row, bookmark,
-					     (GtkDestroyNotify) gtk_object_unref);
+					     (GtkDestroyNotify) g_object_unref);
 
 		pixbuf = bonobo_ui_util_xml_to_pixbuf (item->icon);
 		install_icon (list, new_row, pixbuf);
 		if (pixbuf != NULL) {
-			gdk_pixbuf_unref (pixbuf);
+			g_object_unref (pixbuf);
 		}
 		
 		gtk_clist_columns_autosize (list);
@@ -255,27 +247,17 @@ button_release_callback (GtkCList *list,
 }
 
 static void
-history_changed_callback (NautilusHistoryView *view,
-			  Nautilus_History *list,
-			  gpointer callback_data)
+history_changed_callback (NautilusHistoryView    *view,
+			  const Nautilus_History *history,
+			  gpointer                callback_data)
 {
 	g_assert (view == callback_data);
 
-	update_history (view, list);
+	update_history (view, history);
 }
 
 static void
-nautilus_history_view_initialize_class (NautilusHistoryViewClass *klass)
-{
-	GtkObjectClass *object_class;
-	
-	object_class = GTK_OBJECT_CLASS (klass);
-	
-	object_class->destroy = nautilus_history_view_destroy;
-}
-
-static void
-nautilus_history_view_initialize (NautilusHistoryView *view)
+nautilus_history_view_instance_init (NautilusHistoryView *view)
 {
 	GtkCList *list;
 	GtkWidget *window;
@@ -297,26 +279,29 @@ nautilus_history_view_initialize (NautilusHistoryView *view)
 	
 	nautilus_view_construct (NAUTILUS_VIEW (view), window);
 
-	gtk_object_ref (GTK_OBJECT (list));
+	g_object_ref (list);
 	view->list = list;
 
-	gtk_signal_connect (GTK_OBJECT (list),
-			    "button-press-event",
-			    button_press_callback,
-			    view);
-	gtk_signal_connect (GTK_OBJECT (list),
-			    "button-release-event",
-			    button_release_callback,
-			    view);
+	g_signal_connect (list,
+			  "button-press-event",
+			  G_CALLBACK (button_press_callback),
+			  view);
+	g_signal_connect (list,
+			  "button-release-event",
+			  G_CALLBACK (button_release_callback),
+			  view);
 
-	gtk_signal_connect (GTK_OBJECT (view),
-			    "history_changed", 
-			    history_changed_callback,
-			    view);
+	nautilus_view_set_listener_mask (NAUTILUS_VIEW (view),
+					 NAUTILUS_VIEW_LISTEN_HISTORY);
+
+	g_signal_connect (view,
+			  "history_changed",
+			  G_CALLBACK (history_changed_callback),
+			  view);
 }
 
 static void
-nautilus_history_view_destroy (GtkObject *object)
+nautilus_history_view_finalize (GObject *object)
 {
 	NautilusHistoryView *view;
 	
@@ -326,19 +311,22 @@ nautilus_history_view_destroy (GtkObject *object)
 		*view->external_destroyed_flag = TRUE;
 	}
 
-	gtk_object_unref (GTK_OBJECT (view->list));
+	g_object_unref (view->list);
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+}
+
+static void
+nautilus_history_view_class_init (NautilusHistoryViewClass *klass)
+{
+	G_OBJECT_CLASS (klass)->finalize = nautilus_history_view_finalize;
 }
 
 int
 main (int argc, char *argv[])
 {
-	/* Make criticals and warnings stop in the debugger if NAUTILUS_DEBUG is set.
-	 * Unfortunately, this has to be done explicitly for each domain.
-	 */
 	if (g_getenv ("NAUTILUS_DEBUG") != NULL) {
-		eel_make_warnings_and_criticals_stop_in_debugger (G_LOG_DOMAIN, NULL);
+		eel_make_warnings_and_criticals_stop_in_debugger ();
 	}
 
 	return nautilus_view_standard_main ("nautilus_history-view",
@@ -350,6 +338,6 @@ main (int argc, char *argv[])
 					    FACTORY_IID,
 					    VIEW_IID,
 					    nautilus_view_create_from_get_type_function,
-					    nautilus_global_preferences_initialize,
+					    nautilus_global_preferences_init,
 					    nautilus_history_view_get_type);
 }
