@@ -21,7 +21,7 @@
    Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
   
-   Author: Darin Adler <darin@eazel.com>
+   Author: Darin Adler <darin@bentspoon.com>
 */
 
 #include <config.h>
@@ -70,13 +70,13 @@ desktop_background_realized (NautilusIconContainer *icon_container, void *discon
 
         if ((gboolean) GPOINTER_TO_INT (disconnect_signal)) {
 		gtk_signal_disconnect_by_func (GTK_OBJECT (icon_container),
-					       GTK_SIGNAL_FUNC (desktop_background_realized),
+					       G_CALLBACK (desktop_background_realized),
 					       disconnect_signal);
 	}
 
 	background = eel_get_widget_background (GTK_WIDGET (icon_container));
 
-	gtk_object_set_data (GTK_OBJECT (background), "icon_container", (gpointer) icon_container);
+	g_object_set_data (G_OBJECT (background), "icon_container", (gpointer) icon_container);
 
 	nautilus_file_update_desktop_pixmaps (background);
 }
@@ -92,7 +92,7 @@ nautilus_connect_desktop_background_to_file_metadata (NautilusIconContainer *ico
 
 	background = eel_get_widget_background (GTK_WIDGET (icon_container));
 
-	gtk_object_set_data (GTK_OBJECT (background), "theme_source", (gpointer) desktop_theme_source);
+	g_object_set_data (G_OBJECT (background), "theme_source", (gpointer) desktop_theme_source);
 
 	/* Strictly speaking, we don't need to know about metadata changes, since
 	 * the desktop setting aren't stored there. But, hooking up to metadata
@@ -107,35 +107,35 @@ nautilus_connect_desktop_background_to_file_metadata (NautilusIconContainer *ico
 	if (GTK_WIDGET_REALIZED (icon_container)) {
 		desktop_background_realized (icon_container, GINT_TO_POINTER (FALSE));
 	} else {
-		gtk_signal_connect (GTK_OBJECT (icon_container), "realize", GTK_SIGNAL_FUNC (desktop_background_realized), GINT_TO_POINTER (TRUE));
+		g_signal_connect (icon_container, "realize", G_CALLBACK (desktop_background_realized), GINT_TO_POINTER (TRUE));
 	}
 
 	nautilus_file_background_receive_root_window_changes (background); 
 }
 
 static gboolean
-eel_background_is_desktop (EelBackground *background)
+background_is_desktop (EelBackground *background)
 {
 	/* == works because we're carful to always use the same string.
 	 */
-	return gtk_object_get_data (GTK_OBJECT (background), "theme_source") == desktop_theme_source;
+	return g_object_get_data (G_OBJECT (background), "theme_source") == desktop_theme_source;
 }
 
 static const char *nautilus_file_background_peek_theme_source (EelBackground *background)
 {
 	char *theme_source;
 
-	theme_source = gtk_object_get_data (GTK_OBJECT (background), "theme_source");
+	theme_source = g_object_get_data (G_OBJECT (background), "theme_source");
 
 	return theme_source != NULL ? theme_source : default_theme_source;
 }
 
 static GdkWindow *
-eel_background_get_desktop_background_window (EelBackground *background)
+background_get_desktop_background_window (EelBackground *background)
 {
 	gpointer layout;
 
-	layout = gtk_object_get_data (GTK_OBJECT (background), "icon_container");
+	layout = g_object_get_data (G_OBJECT (background), "icon_container");
 	return layout != NULL ? GTK_LAYOUT (layout)->bin_window : NULL;
 }
 
@@ -283,7 +283,7 @@ nautilus_file_background_read_desktop_settings (char **color,
 		 	default:
 		 		g_assert_not_reached ();
 			case WALLPAPER_EMBOSSED:
-				/* FIXME bugzilla.eazel.com 2193: we don't support embossing.
+				/* FIXME bugzilla.gnome.org 42193: we don't support embossing.
 				 * Just treat it as centered - ugh.
 				 */
 			case WALLPAPER_CENTERED:
@@ -394,8 +394,8 @@ nautilus_file_background_write_desktop_settings (char *color, char *image, EelBa
 		/* We set it to white here because that's how backgrounds with a NULL color
 		 * are drawn by Nautilus - due to usage of eel_gdk_color_parse_with_white_default.
 		 */
-		gnome_config_set_string ("/Background/Default/color1", "rgb:FFFF/FFFF/FFFF");		
-		gnome_config_set_string ("/Background/Default/color2", "rgb:FFFF/FFFF/FFFF");		
+		gnome_config_set_string ("/Background/Default/color1", "#FFFFFF");		
+		gnome_config_set_string ("/Background/Default/color2", "#FFFFFF");		
 		gnome_config_set_string ("/Background/Default/simple", "solid");
 		gnome_config_set_string ("/Background/Default/gradient", "vertical");
 	}
@@ -471,7 +471,7 @@ static int
 call_settings_changed (EelBackground *background)
 {
 	NautilusFile *file;
-	file = gtk_object_get_data (GTK_OBJECT (background), "eel_background_file");
+	file = g_object_get_data (G_OBJECT (background), "eel_background_file");
 	if (file) {
 		saved_settings_changed_callback (file, background);
 	}
@@ -493,7 +493,7 @@ nautilus_file_background_event_filter (GdkXEvent *gdk_xevent, GdkEvent *event, g
 
 	xevent = (XEvent *) gdk_xevent;
 
-	if (xevent->type == PropertyNotify && xevent->xproperty.atom == gdk_atom_intern("ESETROOT_PMAP_ID", TRUE)) {
+	if (xevent->type == PropertyNotify && xevent->xproperty.atom == gdk_x11_get_xatom_by_name ("ESETROOT_PMAP_ID")) {
 
 		/* If we caused it, ignore it.
 		 */
@@ -503,7 +503,7 @@ nautilus_file_background_event_filter (GdkXEvent *gdk_xevent, GdkEvent *event, g
 		}
 		
 	    	background = EEL_BACKGROUND (data);
-	    	/* FIXME bugzilla.eazel.com 2220:
+	    	/* FIXME bugzilla.gnome.org 42220:
 	    	 * We'd like to call saved_settings_changed_callback right here, directly.
 	    	 * However, the current version of the property-background capplet saves
 	    	 * the new setting in gnome_config AFTER setting the root window's property -
@@ -537,16 +537,15 @@ nautilus_file_background_receive_root_window_changes (EelBackground *background)
 	XSelectInput (GDK_DISPLAY (), GDK_ROOT_WINDOW (), attribs.your_event_mask | PropertyChangeMask);
 	
 	gdk_flush ();
-
 	gdk_error_trap_pop ();
 
-	gtk_signal_connect (GTK_OBJECT (background),
+	g_signal_connect (background,
  			    "destroy",
-			    GTK_SIGNAL_FUNC (desktop_background_destroyed_callback),
+			    G_CALLBACK (desktop_background_destroyed_callback),
 			    NULL);
 }
 
-/* Create a persistant pixmap. We create a separate display
+/* Create a persistent pixmap. We create a separate display
  * and set the closedown mode on it to RetainPermanent
  * (copied from gnome-source/control-panels/capplets/background-properties/render-background.c)
  */
@@ -558,7 +557,7 @@ make_root_pixmap (gint width, gint height)
 
 	gdk_flush ();
 
-	display = XOpenDisplay (gdk_display_name);
+	display = XOpenDisplay (DisplayString (GDK_DISPLAY ()));
 
 	XSetCloseDownMode (display, RetainPermanent);
 
@@ -572,24 +571,6 @@ make_root_pixmap (gint width, gint height)
 	return gdk_pixmap_foreign_new (result);
 }
 
-/* (copied from gnome-source/control-panels/capplets/background-properties/render-background.c)
- */
-static void
-dispose_root_pixmap (GdkPixmap *pixmap)
-{
-	/* Unrefing a foreign pixmap causes it to be destroyed - so we include
-	 * this bad hack, that will work for GTK+-1.2 until the problem
-	 * is fixed in the next release
-	 */
-
-	GdkWindowPrivate *private = (GdkWindowPrivate *)pixmap;
-	
-	gdk_xid_table_remove (private->xwindow);
-	g_dataset_destroy (private);
-	g_free (private);
-
-}
-
 /* Set the root pixmap, and properties pointing to it. We
  * do this atomically with XGrabServer to make sure that
  * we won't leak the pixmap if somebody else it setting
@@ -606,23 +587,25 @@ set_root_pixmap (GdkPixmap *pixmap)
 	gulong  bytes_after;
 	guchar *data_esetroot;
 	Pixmap  pixmap_id;
-	GdkAtom type;
+	Atom type;
 
 	data_esetroot = NULL;
 
 	XGrabServer (GDK_DISPLAY());
 
 	result = XGetWindowProperty (GDK_DISPLAY(), GDK_ROOT_WINDOW(),
-				     gdk_atom_intern("ESETROOT_PMAP_ID", FALSE),
+				     gdk_x11_get_xatom_by_name ("ESETROOT_PMAP_ID"),
 				     0L, 1L, False, XA_PIXMAP,
 				     &type, &format, &nitems, &bytes_after,
 				     &data_esetroot);
 
-	if (result == Success && type == XA_PIXMAP && format == 32 && nitems == 1) {
-		XKillClient(GDK_DISPLAY(), *(Pixmap*)data_esetroot);
-	}
-	
 	if (data_esetroot != NULL) {
+		if (result == Success && type == XA_PIXMAP && format == 32 && nitems == 1) {
+			gdk_error_trap_push ();
+			XKillClient(GDK_DISPLAY(), *(Pixmap *)data_esetroot);
+			gdk_flush ();
+			gdk_error_trap_pop ();
+		}
 		XFree (data_esetroot);
 	}
 
@@ -631,15 +614,15 @@ set_root_pixmap (GdkPixmap *pixmap)
 	pixmap_id = GDK_WINDOW_XWINDOW (pixmap);
 
 	XChangeProperty (GDK_DISPLAY(), GDK_ROOT_WINDOW(),
-			 gdk_atom_intern("ESETROOT_PMAP_ID", FALSE), XA_PIXMAP,
+			 gdk_x11_get_xatom_by_name ("ESETROOT_PMAP_ID"), XA_PIXMAP,
 			 32, PropModeReplace,
 			 (guchar *) &pixmap_id, 1);
 	XChangeProperty (GDK_DISPLAY(), GDK_ROOT_WINDOW(),
-			 gdk_atom_intern("_XROOTPMAP_ID", FALSE), XA_PIXMAP,
+			 gdk_x11_get_xatom_by_name ("_XROOTPMAP_ID"), XA_PIXMAP,
 			 32, PropModeReplace,
 			 (guchar *) &pixmap_id, 1);
 
-	XSetWindowBackgroundPixmap (GDK_DISPLAY(), GDK_ROOT_WINDOW(), pixmap_id);
+	XSetWindowBackgroundPixmap (GDK_DISPLAY (), GDK_ROOT_WINDOW (), pixmap_id);
 	XClearWindow (GDK_DISPLAY (), GDK_ROOT_WINDOW ());
 
 	XUngrabServer (GDK_DISPLAY());
@@ -658,7 +641,7 @@ image_loading_done_callback (EelBackground *background, gboolean successful_load
 
         if ((gboolean) GPOINTER_TO_INT (disconnect_signal)) {
 		gtk_signal_disconnect_by_func (GTK_OBJECT (background),
-					       GTK_SIGNAL_FUNC (image_loading_done_callback),
+					       G_CALLBACK (image_loading_done_callback),
 					       disconnect_signal);
 	}
 
@@ -672,19 +655,12 @@ image_loading_done_callback (EelBackground *background, gboolean successful_load
 
 	set_root_pixmap (pixmap);
 
-	background_window = eel_background_get_desktop_background_window (background);
+	background_window = background_get_desktop_background_window (background);
 	if (background_window != NULL) {
 		gdk_window_set_back_pixmap (background_window, pixmap, FALSE);
 	}
 
-	/* We'd like to simply unref pixmap here, but due to a bug in gdk's handling of
-	 * foreign pixmaps, we can't - it would free the X resource.
-	 *
-	 * gdk_window_set_back_pixmap does not need the gdk pixmap object to stick around.
-	 * It simply uses X resource inside it. dispose_root_pixmap free's the gdk object
-	 * and not the X resource.
-	 */
-	dispose_root_pixmap (pixmap);
+        gdk_pixmap_unref (pixmap);
 }
 
 static void
@@ -693,9 +669,9 @@ nautilus_file_update_desktop_pixmaps (EelBackground *background)
 	if (eel_background_is_loaded (background)) {
 		image_loading_done_callback (background, TRUE, GINT_TO_POINTER (FALSE));
 	} else {
-		gtk_signal_connect (GTK_OBJECT (background),
+		g_signal_connect (background,
 				    "image_loading_done",
-				    GTK_SIGNAL_FUNC (image_loading_done_callback),
+				    G_CALLBACK (image_loading_done_callback),
 				    GINT_TO_POINTER (TRUE));
 	}
 }
@@ -763,20 +739,20 @@ background_changed_callback (EelBackground *background,
         
         g_assert (EEL_IS_BACKGROUND (background));
         g_assert (NAUTILUS_IS_FILE (file));
-        g_assert (gtk_object_get_data (GTK_OBJECT (background), "eel_background_file") == file);
+        g_assert (g_object_get_data (G_OBJECT (background), "eel_background_file") == file);
         
 
 	color = eel_background_get_color (background);
 	image = eel_background_get_image_uri (background);
 
-	if (eel_background_is_desktop (background)) {
+	if (background_is_desktop (background)) {
 		nautilus_file_background_write_desktop_settings (color, image, eel_background_get_image_placement (background));
 	} else {
 	        /* Block the other handler while we are writing metadata so it doesn't
 	         * try to change the background.
 	         */
 	        gtk_signal_handler_block_by_func (GTK_OBJECT (file),
-	                                          saved_settings_changed_callback,
+	                                          G_CALLBACK (saved_settings_changed_callback),
 	                                          background);
 
 		nautilus_file_set_metadata (file,
@@ -791,14 +767,14 @@ background_changed_callback (EelBackground *background,
 						 
 	        /* Unblock the handler. */
 	        gtk_signal_handler_unblock_by_func (GTK_OBJECT (file),
-	                                            saved_settings_changed_callback,
+	                                            G_CALLBACK (saved_settings_changed_callback),
 	                                            background);
 	}
 
 	g_free (color);
 	g_free (image);
 	
-	if (eel_background_is_desktop (background)) {
+	if (background_is_desktop (background)) {
 		nautilus_file_update_desktop_pixmaps (background);
 	}
 }
@@ -813,10 +789,10 @@ initialize_background_from_settings (NautilusFile *file,
 	
         g_assert (NAUTILUS_IS_FILE (file));
         g_assert (EEL_IS_BACKGROUND (background));
-        g_assert (gtk_object_get_data (GTK_OBJECT (background), "eel_background_file")
+        g_assert (g_object_get_data (G_OBJECT (background), "eel_background_file")
                   == file);
 
-	if (eel_background_is_desktop (background)) {
+	if (background_is_desktop (background)) {
 		nautilus_file_background_read_desktop_settings (&color, &image, &placement);
 	} else {
 		color = nautilus_file_get_metadata (file,
@@ -839,16 +815,21 @@ initialize_background_from_settings (NautilusFile *file,
          * in the metadata so it doesn't try to change the metadata.
          */
         gtk_signal_handler_block_by_func (GTK_OBJECT (background),
-                                          background_changed_callback,
+                                          G_CALLBACK (background_changed_callback),
                                           file);
 
 	eel_background_set_color (background, color);     
-	eel_background_set_image_uri (background, image);
+        if (background_is_desktop(background)) {
+                eel_background_set_image_uri_sync (background, image);
+        }
+        else {
+                eel_background_set_image_uri (background, image);
+        }
         eel_background_set_image_placement (background, placement);
 	
 	/* Unblock the handler. */
 	gtk_signal_handler_unblock_by_func (GTK_OBJECT (background),
-                                            background_changed_callback,
+                                            G_CALLBACK (background_changed_callback),
                                             file);
 	
 	g_free (color);
@@ -862,7 +843,7 @@ saved_settings_changed_callback (NautilusFile *file,
 {
 	initialize_background_from_settings (file, background);
 	
-	if (eel_background_is_desktop (background)) {
+	if (background_is_desktop (background)) {
 		nautilus_file_update_desktop_pixmaps (background);
 	}
 }
@@ -875,7 +856,7 @@ nautilus_file_background_theme_changed (gpointer user_data)
 	EelBackground *background;
 
 	background = EEL_BACKGROUND (user_data);
-	file = gtk_object_get_data (GTK_OBJECT (background), "eel_background_file");
+	file = g_object_get_data (G_OBJECT (background), "eel_background_file");
 	if (file) {
 		saved_settings_changed_callback (file, background);
 	}
@@ -886,14 +867,14 @@ static void
 background_reset_callback (EelBackground *background,
                            NautilusFile       *file)
 {
-	if (eel_background_is_desktop (background)) {
+	if (background_is_desktop (background)) {
 		nautilus_file_background_write_desktop_default_settings ();
 	} else {
 	        /* Block the other handler while we are writing metadata so it doesn't
 	         * try to change the background.
 	         */
 	        gtk_signal_handler_block_by_func (GTK_OBJECT (file),
-	                                          saved_settings_changed_callback,
+	                                          G_CALLBACK (saved_settings_changed_callback),
 	                                          background);
 
 		/* reset the metadata */
@@ -908,7 +889,7 @@ background_reset_callback (EelBackground *background,
                                             NULL);
 	        /* Unblock the handler. */
 	        gtk_signal_handler_unblock_by_func (GTK_OBJECT (file),
-	                                            saved_settings_changed_callback,
+	                                            G_CALLBACK (saved_settings_changed_callback),
 	                                            background);
 	}
 
@@ -921,7 +902,7 @@ background_destroyed_callback (EelBackground *background,
                                NautilusFile       *file)
 {
         gtk_signal_disconnect_by_func (GTK_OBJECT (file),
-                                       GTK_SIGNAL_FUNC (saved_settings_changed_callback),
+                                       G_CALLBACK (saved_settings_changed_callback),
                                        background);
         nautilus_file_monitor_remove (file, background);
 	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_THEME,
@@ -942,7 +923,7 @@ nautilus_connect_background_to_file_metadata (GtkWidget    *widget,
 	background = eel_get_widget_background (widget);
 
 	/* Check if it is already connected. */
-	old_file = gtk_object_get_data (GTK_OBJECT (background), "eel_background_file");
+	old_file = g_object_get_data (G_OBJECT (background), "eel_background_file");
 	if (old_file == file) {
 		return;
 	}
@@ -951,16 +932,16 @@ nautilus_connect_background_to_file_metadata (GtkWidget    *widget,
 	if (old_file != NULL) {
 		g_assert (NAUTILUS_IS_FILE (old_file));
 		gtk_signal_disconnect_by_func (GTK_OBJECT (background),
-                                               GTK_SIGNAL_FUNC (background_changed_callback),
+                                               G_CALLBACK (background_changed_callback),
                                                old_file);
 		gtk_signal_disconnect_by_func (GTK_OBJECT (background),
-                                               GTK_SIGNAL_FUNC (background_destroyed_callback),
+                                               G_CALLBACK (background_destroyed_callback),
                                                old_file);
 		gtk_signal_disconnect_by_func (GTK_OBJECT (background),
-                                               GTK_SIGNAL_FUNC (background_reset_callback),
+                                               G_CALLBACK (background_reset_callback),
                                                old_file);
 		gtk_signal_disconnect_by_func (GTK_OBJECT (old_file),
-                                               GTK_SIGNAL_FUNC (saved_settings_changed_callback),
+                                               G_CALLBACK (saved_settings_changed_callback),
                                                background);
 		nautilus_file_monitor_remove (old_file, background);
 		eel_preferences_remove_callback (NAUTILUS_PREFERENCES_THEME,
@@ -971,32 +952,32 @@ nautilus_connect_background_to_file_metadata (GtkWidget    *widget,
 
         /* Attach the new directory. */
         nautilus_file_ref (file);
-        gtk_object_set_data_full (GTK_OBJECT (background),
-                                  "eel_background_file",
-                                  file,
-                                  (GtkDestroyNotify) nautilus_file_unref);
+        g_object_set_data_full (G_OBJECT (background),
+                                "eel_background_file",
+                                file,
+                                (GtkDestroyNotify) nautilus_file_unref);
 
         /* Connect new signal handlers. */
         if (file != NULL) {
-                gtk_signal_connect (GTK_OBJECT (background),
+                g_signal_connect (background,
                                     "settings_changed",
-                                    GTK_SIGNAL_FUNC (background_changed_callback),
+                                    G_CALLBACK (background_changed_callback),
                                     file);
-                gtk_signal_connect (GTK_OBJECT (background),
+                g_signal_connect (background,
                                     "destroy",
-                                    GTK_SIGNAL_FUNC (background_destroyed_callback),
+                                    G_CALLBACK (background_destroyed_callback),
                                     file);
-                gtk_signal_connect (GTK_OBJECT (background),
+                g_signal_connect (background,
 				    "reset",
-				    GTK_SIGNAL_FUNC (background_reset_callback),
+				    G_CALLBACK (background_reset_callback),
 				    file);
-		gtk_signal_connect (GTK_OBJECT (file),
+		g_signal_connect (file,
                                     "changed",
-                                    GTK_SIGNAL_FUNC (saved_settings_changed_callback),
+                                    G_CALLBACK (saved_settings_changed_callback),
                                     background);
         	
 		/* arrange to receive file metadata */
-                attributes = g_list_append (NULL, NAUTILUS_FILE_ATTRIBUTE_METADATA);
+                attributes = g_list_prepend (NULL, NAUTILUS_FILE_ATTRIBUTE_METADATA);
 		nautilus_file_monitor_add (file,
                                            background,
                                            attributes);					     
