@@ -25,10 +25,9 @@
 #ifndef NAUTILUS_HORIZONTAL_SPLITTER_H
 #define NAUTILUS_HORIZONTAL_SPLITTER_H
 
-#include <libgnome/gnome-defs.h>
-#include "e-hpaned.h"
+#include <gtk/gtkhpaned.h>
 
-BEGIN_GNOME_DECLS
+G_BEGIN_DECLS
 
 #define NAUTILUS_TYPE_HORIZONTAL_SPLITTER            (nautilus_horizontal_splitter_get_type ())
 #define NAUTILUS_HORIZONTAL_SPLITTER(obj)            (GTK_CHECK_CAST ((obj), NAUTILUS_TYPE_HORIZONTAL_SPLITTER, NautilusHorizontalSplitter))
@@ -39,12 +38,12 @@ BEGIN_GNOME_DECLS
 typedef struct NautilusHorizontalSplitterDetails NautilusHorizontalSplitterDetails;
 
 typedef struct {
-	EHPaned					parent_slot;
+	GtkHPaned				parent_slot;
 	NautilusHorizontalSplitterDetails	*details;
 } NautilusHorizontalSplitter;
 
 typedef struct {
-	EHPanedClass				parent_slot;
+	GtkHPanedClass				parent_slot;
 } NautilusHorizontalSplitterClass;
 
 /* NautilusHorizontalSplitter public methods */
@@ -55,6 +54,6 @@ void	   nautilus_horizontal_splitter_collapse	(NautilusHorizontalSplitter *split
 void	   nautilus_horizontal_splitter_expand		(NautilusHorizontalSplitter *splitter);
 void	   nautilus_horizontal_splitter_toggle_position	(NautilusHorizontalSplitter *splitter);
 
-END_GNOME_DECLS
+G_END_DECLS
 
 #endif /* NAUTILUS_HORIZONTAL_SPLITTER_H */
