@@ -35,9 +35,8 @@
 #include <eel/eel-string.h>
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-xml-extensions.h>
-#include <gnome-xml/parser.h>
-#include <gnome-xml/xmlmemory.h>
-#include <libgnome/gnome-defs.h>
+#include <libxml/parser.h>
+#include <libxml/xmlmemory.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnome/gnome-util.h>
 #include <libgnome/gnome-util.h>
@@ -185,7 +184,7 @@ nautilus_theme_get_theme_data_from_theme (const char *resource_name, const char
 	if (theme_document != NULL) {
 		/* fetch the resource node */			
 		resource_node = eel_xml_get_child_by_name (xmlDocGetRootElement (theme_document), resource_name);
-		if (resource_node) {		
+		if (resource_node) {
 			temp_str = xmlGetProp(resource_node, property_name);
 			if (temp_str) {
 				theme_data = g_strdup (temp_str);
@@ -338,7 +337,7 @@ nautilus_theme_make_preview_pixbuf (const char *theme_name)
 	
 	pixbuf_file = nautilus_pixmap_file (theme_preview_name);
 	if (pixbuf_file != NULL) {
-		pixbuf = gdk_pixbuf_new_from_file (pixbuf_file);
+		pixbuf = gdk_pixbuf_new_from_file (pixbuf_file, NULL);
 		g_free (pixbuf_file);
 		return pixbuf;
 	} else {
@@ -348,7 +347,7 @@ nautilus_theme_make_preview_pixbuf (const char *theme_name)
 		g_free (user_themes_directory);
 		
 		if (g_file_exists (pixbuf_file)) {
-			pixbuf = gdk_pixbuf_new_from_file (pixbuf_file);
+			pixbuf = gdk_pixbuf_new_from_file (pixbuf_file, NULL);
 			g_free (pixbuf_file);
 			return pixbuf;
 		}  else {
@@ -399,14 +398,9 @@ nautilus_theme_make_preview_pixbuf (const char *theme_name)
 	
 	/* load the icon that we found and return it */
 	if (eel_istr_has_suffix (pixbuf_file, ".svg")) {
-		FILE *f = fopen (pixbuf_file, "rb");
-		if (f != NULL) {
-			pixbuf = rsvg_render_file (f, 1.0);
-			fclose (f);
-		}
-	
+		pixbuf = rsvg_pixbuf_from_file (pixbuf_file, NULL);
 	} else {
-		pixbuf = gdk_pixbuf_new_from_file (pixbuf_file);
+		pixbuf = gdk_pixbuf_new_from_file (pixbuf_file, NULL);
 	}
 	
 	g_free (pixbuf_file);
@@ -562,10 +556,10 @@ theme_get_description_property (const char *themes_location_uri,
 }
 
 static GList *
-theme_list_insert (GList *theme_list,
-		   const char *themes_location_uri,
-		   const char *theme_name,
-		   gboolean builtin)
+theme_list_prepend (GList *theme_list,
+		    const char *themes_location_uri,
+		    const char *theme_name,
+		    gboolean builtin)
 {
 	ThemeAttibutes *attributes;
 	GdkPixbuf *unscaled_preview_pixbuf;
@@ -581,14 +575,14 @@ theme_list_insert (GList *theme_list,
 	attributes->preview_pixbuf = eel_gdk_pixbuf_scale_down_to_fit (unscaled_preview_pixbuf,
 								       THEME_PREVIEW_ICON_WIDTH,
 								       THEME_PREVIEW_ICON_HEIGHT);
-	gdk_pixbuf_unref (unscaled_preview_pixbuf);
+	g_object_unref (unscaled_preview_pixbuf);
 
 	attributes->builtin = builtin;
 
 	attributes->display_name = theme_get_name_property (themes_location_uri, theme_name);
 	attributes->description = theme_get_description_property (themes_location_uri, theme_name);
 
-	return g_list_append (theme_list, attributes);
+	return g_list_prepend (theme_list, attributes);
 }
 
 static GList *
@@ -606,8 +600,7 @@ theme_get_themes_for_location (const char *themes_location_uri,
 	possible_theme_directories = NULL;
 	result = gnome_vfs_directory_list_load (&possible_theme_directories,
 						themes_location_uri,
-						GNOME_VFS_FILE_INFO_FOLLOW_LINKS,
-						NULL);
+						GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
 	
 	if (result != GNOME_VFS_OK) {
 		return NULL;
@@ -622,15 +615,15 @@ theme_get_themes_for_location (const char *themes_location_uri,
 		if ((file_info->type == GNOME_VFS_FILE_TYPE_DIRECTORY)
 		    && (file_info->name[0] != '.')) {
 			if (has_image_file (themes_location_uri, file_info->name, "i-directory" )) {
-				themes = theme_list_insert (themes,
-							    themes_location_uri,
-							    file_info->name,
-							    builtin);
+				themes = theme_list_prepend (themes,
+							     themes_location_uri,
+							     file_info->name,
+							     builtin);
 			}
 		}
 	}
 
-	return themes;
+	return g_list_reverse (themes);
 }
 
 static GList *
@@ -674,10 +667,9 @@ theme_get_default_themes (void)
  	char *pixmap_directory_uri;
 	GList *default_themes;
 
-	default_themes = NULL;
 	pixmap_directory = nautilus_get_pixmap_directory ();
 	pixmap_directory_uri = gnome_vfs_get_uri_from_local_path (pixmap_directory);
-	default_themes = theme_list_insert (default_themes, pixmap_directory_uri, "default", TRUE);
+	default_themes = theme_list_prepend (NULL, pixmap_directory_uri, "default", TRUE);
 	g_free (pixmap_directory_uri);
 	g_free (pixmap_directory);
 
@@ -729,7 +721,7 @@ attributes_free (gpointer data,
 	g_free (attributes->display_name);
 	g_free (attributes->description);
 	if (attributes->preview_pixbuf != NULL) {
-		gdk_pixbuf_unref (attributes->preview_pixbuf);
+		g_object_unref (attributes->preview_pixbuf);
 	}
 }
 
@@ -784,7 +776,7 @@ nautilus_theme_remove_user_theme (const char *theme_to_remove_name)
 	theme_to_remove_path = nautilus_make_path (user_themes_directory, theme_to_remove_name);
 	g_free (user_themes_directory);
 	
-	uri_list = g_list_append (NULL, gnome_vfs_uri_new (theme_to_remove_path));			
+	uri_list = g_list_prepend (NULL, gnome_vfs_uri_new (theme_to_remove_path));			
 	g_free (theme_to_remove_path);
 
 	result = gnome_vfs_xfer_delete_list (uri_list, GNOME_VFS_XFER_RECURSIVE,
@@ -806,7 +798,7 @@ nautilus_theme_install_user_theme (const char *theme_to_install_path)
 	char *theme_destination_path;
 
 	if (theme_to_install_path == NULL
-	    || !g_file_test (theme_to_install_path, G_FILE_TEST_EXISTS | G_FILE_TEST_ISDIR)) {
+	    || !g_file_test (theme_to_install_path, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_DIR)) {
 		return NAUTILUS_THEME_INSTALL_NOT_A_THEME_DIRECTORY;
 	}
 
