@@ -26,11 +26,11 @@
 #include <config.h>
 #include <gtk/gtk.h>
 
-#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
 #include <libnautilus/nautilus-undo.h>
 
 #include <eel/eel-gtk-macros.h>
+#include <string.h>
 
 #include "nautilus-undo-signal-handlers.h"
 
@@ -47,7 +47,7 @@ typedef struct {
 } EditableUndoObjectData;
 
 
-static void restore_editable_from_undo_snapshot_callback (GtkObject 	*target, 
+static void restore_editable_from_undo_snapshot_callback (GObject 	*target, 
 							  gpointer 	callback_data);
 static void editable_register_edit_undo 		 (GtkEditable 	*editable);
 static void free_editable_object_data 			 (gpointer 	data);
@@ -76,13 +76,13 @@ nautilus_undo_set_up_nautilus_entry_for_undo (NautilusEntry *entry)
 
 	data = g_new(EditableUndoObjectData, 1);
 	data->undo_registered = FALSE;
-	gtk_object_set_data_full (GTK_OBJECT (entry), "undo_registered", 
-				  data, free_editable_object_data);
+	g_object_set_data_full (G_OBJECT (entry), "undo_registered", 
+				data, free_editable_object_data);
 
 	/* Connect to entry signals */
-	gtk_signal_connect (GTK_OBJECT (entry), 
+	g_signal_connect (entry, 
 		    "user_changed",
-		    GTK_SIGNAL_FUNC (nautilus_entry_user_changed_callback),
+		    G_CALLBACK (nautilus_entry_user_changed_callback),
 		    NULL);
 }
 
@@ -95,7 +95,7 @@ nautilus_undo_tear_down_nautilus_entry_for_undo (NautilusEntry *entry)
 
 	/* Disconnect from entry signals */
 	gtk_signal_disconnect_by_func (GTK_OBJECT (entry), 
-		    GTK_SIGNAL_FUNC (nautilus_entry_user_changed_callback),		    
+		    G_CALLBACK (nautilus_entry_user_changed_callback),		    
 		    NULL);
 
 }
@@ -150,7 +150,7 @@ editable_register_edit_undo (GtkEditable *editable)
 	}
 
 	/* Check our undo registered flag */
-	data = gtk_object_get_data (GTK_OBJECT (editable), "undo_registered");
+	data = g_object_get_data (G_OBJECT (editable), "undo_registered");
 	if (data == NULL) {
 		g_warning ("Undo data is NULL");
 		return;
@@ -161,14 +161,15 @@ editable_register_edit_undo (GtkEditable *editable)
 		return;
 	}
 	
-	undo_data = g_new (EditableUndoData, 1);
+	undo_data = g_new0 (EditableUndoData, 1);
 	undo_data->undo_text = g_strdup (gtk_editable_get_chars (editable, 0, -1));
 	undo_data->position = gtk_editable_get_position (editable);
-	undo_data->selection_start = editable->selection_start_pos;
-	undo_data->selection_end = editable->selection_end_pos;
+	gtk_editable_get_selection_bounds (editable,
+					   &undo_data->selection_start,
+					   &undo_data->selection_end);
 
 	nautilus_undo_register
-		(GTK_OBJECT (editable),
+		(G_OBJECT (editable),
 		 restore_editable_from_undo_snapshot_callback,
 		 undo_data,
 		 (GDestroyNotify) free_editable_undo_data,
@@ -191,21 +192,21 @@ nautilus_undo_set_up_editable_for_undo (GtkEditable *editable)
 	}
 
 	/* Connect to editable signals */
-	gtk_signal_connect (GTK_OBJECT (editable), 
+	g_signal_connect (editable, 
 		    "insert_text",
-		    GTK_SIGNAL_FUNC (editable_insert_text_callback),
+		    G_CALLBACK (editable_insert_text_callback),
 		    NULL);
 	
-	gtk_signal_connect (GTK_OBJECT (editable), 
+	g_signal_connect (editable, 
 		    "delete_text",
-		    GTK_SIGNAL_FUNC (editable_delete_text_callback),
+		    G_CALLBACK (editable_delete_text_callback),
 		    NULL);
 
 
 	data = g_new (EditableUndoObjectData, 1);
 	data->undo_registered = FALSE;
-	gtk_object_set_data_full (GTK_OBJECT (editable), "undo_registered", 
-				  data, free_editable_object_data);
+	g_object_set_data_full (G_OBJECT (editable), "undo_registered", 
+				data, free_editable_object_data);
 }
 
 void
@@ -217,11 +218,11 @@ nautilus_undo_tear_down_editable_for_undo (GtkEditable *editable)
 
 	/* Disconnect from entry signals */
 	gtk_signal_disconnect_by_func (GTK_OBJECT (editable), 
-		    GTK_SIGNAL_FUNC (editable_insert_text_callback),		    
+		    G_CALLBACK (editable_insert_text_callback),		    
 		    NULL);
 
 	gtk_signal_disconnect_by_func (GTK_OBJECT (editable), 
-		    GTK_SIGNAL_FUNC (editable_delete_text_callback),		    
+		    G_CALLBACK (editable_delete_text_callback),		    
 		    NULL);
 }
 
@@ -230,19 +231,19 @@ nautilus_undo_tear_down_editable_for_undo (GtkEditable *editable)
  * Restore edited text.
  */
 static void
-restore_editable_from_undo_snapshot_callback (GtkObject *target, gpointer callback_data)
+restore_editable_from_undo_snapshot_callback (GObject *target, gpointer callback_data)
 {
 	GtkEditable *editable;
 	GtkWindow *window;
 	EditableUndoData *undo_data;
 	EditableUndoObjectData *data;
 	gint position;
-		
+	
 	editable = GTK_EDITABLE (target);
 	undo_data = (EditableUndoData *) callback_data;
 
 	/* Check our undo registered flag */
-	data = gtk_object_get_data (target, "undo_registered");
+	data = g_object_get_data (target, "undo_registered");
 	if (data == NULL) {
 		g_warning ("Undo regisetred flag not found");
 		return;
@@ -261,7 +262,7 @@ restore_editable_from_undo_snapshot_callback (GtkObject *target, gpointer callba
 				  strlen (undo_data->undo_text), &position);
 
 	/* Set focus to widget */
-	window = GTK_WINDOW (gtk_widget_get_toplevel ( GTK_WIDGET (target)));
+	window = GTK_WINDOW (gtk_widget_get_toplevel (GTK_WIDGET (target)));
 	gtk_window_set_focus (window, GTK_WIDGET (editable));
 
 	/* We have to do this call, because the previous call selects all text */
@@ -299,8 +300,6 @@ editable_key_press_event (GtkEditable *editable, GdkEventKey *event, gpointer us
 	case 'z':
 		if ((event->state & GDK_CONTROL_MASK) != 0) {
 			nautilus_undo (GTK_OBJECT (editable));
-			gtk_signal_emit_stop_by_name (GTK_OBJECT (editable),
-						      "key_press_event");
 			return TRUE;
 		}
 		break;
@@ -327,9 +326,9 @@ nautilus_undo_editable_set_undo_key (GtkEditable *editable, gboolean value)
 #ifdef UNDO_ENABLED
 	if (value) {
 		/* Connect to entry signals */
-		gtk_signal_connect (GTK_OBJECT (editable), 
+		g_signal_connect (editable, 
 				    "key_press_event",
-				    GTK_SIGNAL_FUNC (editable_key_press_event),
+				    G_CALLBACK (editable_key_press_event),
 				    NULL);
 	} else {
 		/* FIXME bugzilla.gnome.org 45092: Warns if the handler
@@ -337,7 +336,7 @@ nautilus_undo_editable_set_undo_key (GtkEditable *editable, gboolean value)
 		 * to prevent that little problem.
 		 */
 		gtk_signal_disconnect_by_func (GTK_OBJECT (editable), 
-					       GTK_SIGNAL_FUNC (editable_key_press_event),		    
+					       G_CALLBACK (editable_key_press_event),		    
 					       NULL);
 	}
 #endif
