@@ -30,10 +30,10 @@
 #include <X11/Xatom.h>
 #include <bonobo/bonobo-ui-util.h>
 #include <gtk/gtkmain.h>
-#include <ctype.h>
 #include <dirent.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gnome-extensions.h>
+#include <eel/eel-gobject-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-stock-dialogs.h>
@@ -42,9 +42,7 @@
 #include <fcntl.h>
 #include <gdk/gdkx.h>
 #include <gtk/gtkcheckmenuitem.h>
-#include <libgnome/gnome-dentry.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnome/gnome-mime.h>
 #include <libgnome/gnome-util.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libnautilus-private/nautilus-bonobo-extensions.h>
@@ -86,8 +84,8 @@ struct FMDesktopIconViewDetails
 
 	/* For the desktop rescanning
 	 */
-	guint delayed_init_signal;
-	guint done_loading_signal;
+	gulong delayed_init_signal;
+	gulong done_loading_signal;
 	guint reload_desktop_timeout;
 	gboolean pending_rescan;
 };
@@ -97,8 +95,8 @@ typedef struct {
 	char *mount_path;
 } MountParameters;
 
-static void     fm_desktop_icon_view_initialize                   (FMDesktopIconView      *desktop_icon_view);
-static void     fm_desktop_icon_view_initialize_class             (FMDesktopIconViewClass *klass);
+static void     fm_desktop_icon_view_init                   (FMDesktopIconView      *desktop_icon_view);
+static void     fm_desktop_icon_view_class_init             (FMDesktopIconViewClass *klass);
 static void     fm_desktop_icon_view_trash_state_changed_callback (NautilusTrashMonitor   *trash,
 								   gboolean                state,
 								   gpointer                callback_data);
@@ -124,7 +122,7 @@ static void     update_disks_menu                                 (FMDesktopIcon
 static void     free_volume_black_list                            (FMDesktopIconView      *view);
 static gboolean	volume_link_is_selection 			  (FMDirectoryView 	  *view);
 
-EEL_DEFINE_CLASS_BOILERPLATE (FMDesktopIconView,
+EEL_CLASS_BOILERPLATE (FMDesktopIconView,
 			      fm_desktop_icon_view,
 			      FM_TYPE_ICON_VIEW)
 
@@ -151,7 +149,7 @@ static void
 panel_desktop_area_changed (FMDesktopIconView *icon_view)
 {
 	long *borders = NULL;
-	GdkAtom type_returned;
+	Atom type_returned;
 	int format_returned;
 	unsigned long items_returned;
 	unsigned long bytes_after_return;
@@ -164,8 +162,7 @@ panel_desktop_area_changed (FMDesktopIconView *icon_view)
 	gdk_error_trap_push ();
 	if (XGetWindowProperty (GDK_DISPLAY (),
 				GDK_ROOT_WINDOW (),
-				gdk_atom_intern ("GNOME_PANEL_DESKTOP_AREA",
-						 FALSE),
+				gdk_x11_get_xatom_by_name ("GNOME_PANEL_DESKTOP_AREA"),
 				0 /* long_offset */, 
 				4 /* long_length */,
 				False /* delete */,
@@ -211,7 +208,7 @@ desktop_icon_view_property_filter (GdkXEvent *gdk_xevent,
   
 	switch (xevent->type) {
 	case PropertyNotify:
-		if (xevent->xproperty.atom == gdk_atom_intern ("GNOME_PANEL_DESKTOP_AREA", FALSE)) {
+		if (xevent->xproperty.atom == gdk_x11_get_xatom_by_name ("GNOME_PANEL_DESKTOP_AREA")) {
 			panel_desktop_area_changed (icon_view);
 		}
 		break;
@@ -240,14 +237,13 @@ fm_desktop_icon_view_destroy (GtkObject *object)
 	}
 
 	if (icon_view->details->done_loading_signal != 0) {
-		gtk_signal_disconnect (GTK_OBJECT (fm_directory_view_get_model
-						   (FM_DIRECTORY_VIEW (icon_view))),
-				       icon_view->details->done_loading_signal);
+		g_signal_handler_disconnect (fm_directory_view_get_model (FM_DIRECTORY_VIEW (icon_view)),
+					     icon_view->details->done_loading_signal);
 	}
 
 	if (icon_view->details->delayed_init_signal != 0) {
-		gtk_signal_disconnect (GTK_OBJECT (icon_view),
-				       icon_view->details->delayed_init_signal);
+		g_signal_handler_disconnect (icon_view,
+					     icon_view->details->delayed_init_signal);
 	}
 	
 	/* Delete all of the link files. */
@@ -259,8 +255,9 @@ fm_desktop_icon_view_destroy (GtkObject *object)
 
 	/* Clean up details */	
 	if (icon_view->details->ui != NULL) {
-		bonobo_ui_component_unset_container (icon_view->details->ui);
+		bonobo_ui_component_unset_container (icon_view->details->ui, NULL);
 		bonobo_object_unref (BONOBO_OBJECT (icon_view->details->ui));
+		icon_view->details->ui = NULL;
 	}
 	
 	free_volume_black_list (icon_view);
@@ -271,7 +268,7 @@ fm_desktop_icon_view_destroy (GtkObject *object)
 }
 
 static void
-fm_desktop_icon_view_initialize_class (FMDesktopIconViewClass *klass)
+fm_desktop_icon_view_class_init (FMDesktopIconViewClass *klass)
 {
 	GtkObjectClass		*object_class;
 	FMDirectoryViewClass	*fm_directory_view_class;
@@ -306,7 +303,7 @@ fm_desktop_icon_view_handle_middle_click (NautilusIconContainer *icon_container,
 
 	/* Stop the event because we don't want anyone else dealing with it. */	
 	gdk_flush ();
-	gtk_signal_emit_stop_by_name (GTK_OBJECT(icon_container), "middle_click");
+	g_signal_stop_emission_by_name (icon_container, "middle_click");
 
 	/* build an X event to represent the middle click. */
 	x_event.type = ButtonPress;
@@ -534,23 +531,22 @@ delayed_init (FMDesktopIconView *desktop_icon_view)
 {
 	/* Keep track of the load time. */
 	desktop_icon_view->details->done_loading_signal = 
-		gtk_signal_connect (GTK_OBJECT (fm_directory_view_get_model
-						(FM_DIRECTORY_VIEW (desktop_icon_view))),
-				    "done_loading",
-				    GTK_SIGNAL_FUNC (done_loading), desktop_icon_view);
+		g_signal_connect (fm_directory_view_get_model (FM_DIRECTORY_VIEW (desktop_icon_view)),
+				  "done_loading",
+				  G_CALLBACK (done_loading), desktop_icon_view);
 
 	/* Monitor desktop directory. */
 	desktop_icon_view->details->reload_desktop_timeout =
 		gtk_timeout_add (RESCAN_TIMEOUT, do_desktop_rescan, desktop_icon_view);
 
-	gtk_signal_disconnect (GTK_OBJECT (desktop_icon_view),
-			       desktop_icon_view->details->delayed_init_signal);
+	g_signal_handler_disconnect (desktop_icon_view,
+				     desktop_icon_view->details->delayed_init_signal);
 
 	desktop_icon_view->details->delayed_init_signal = 0;
 }
 
 static void
-fm_desktop_icon_view_initialize (FMDesktopIconView *desktop_icon_view)
+fm_desktop_icon_view_init (FMDesktopIconView *desktop_icon_view)
 {
 	GList *list;
 	NautilusIconContainer *icon_container;
@@ -573,9 +569,9 @@ fm_desktop_icon_view_initialize (FMDesktopIconView *desktop_icon_view)
 	 * way to keep track of the items on the desktop.
 	 */
 	if (!nautilus_monitor_active ()) {
-		desktop_icon_view->details->delayed_init_signal = gtk_signal_connect
-			(GTK_OBJECT (desktop_icon_view), "begin_loading",
-			 GTK_SIGNAL_FUNC (delayed_init), desktop_icon_view);
+		desktop_icon_view->details->delayed_init_signal = g_signal_connect
+			(desktop_icon_view, "begin_loading",
+			 G_CALLBACK (delayed_init), desktop_icon_view);
 	}
 	
 	nautilus_icon_container_set_is_fixed_size (icon_container, TRUE);
@@ -613,42 +609,42 @@ fm_desktop_icon_view_initialize (FMDesktopIconView *desktop_icon_view)
 					     	     create_one_mount_link,
 						     desktop_icon_view);
 	
-	gtk_signal_connect (GTK_OBJECT (icon_container),
+	g_signal_connect (icon_container,
 			    "middle_click",
-			    GTK_SIGNAL_FUNC (fm_desktop_icon_view_handle_middle_click),
+			    G_CALLBACK (fm_desktop_icon_view_handle_middle_click),
 			    desktop_icon_view);
 			    
-	gtk_signal_connect (GTK_OBJECT (icon_container),
+	g_signal_connect (icon_container,
 			    "compare_icons",
-			    GTK_SIGNAL_FUNC (desktop_icons_compare_callback),
+			    G_CALLBACK (desktop_icons_compare_callback),
 			    desktop_icon_view);
 
-	gtk_signal_connect (GTK_OBJECT (desktop_icon_view),
+	g_signal_connect (desktop_icon_view,
 			    "event",
-			    GTK_SIGNAL_FUNC (event_callback),
+			    G_CALLBACK (event_callback),
 			    desktop_icon_view);
 
-	gtk_signal_connect_while_alive (GTK_OBJECT (nautilus_trash_monitor_get ()),
+	eel_signal_connect_while_alive (G_OBJECT (nautilus_trash_monitor_get ()),
 					"trash_state_changed",
-					fm_desktop_icon_view_trash_state_changed_callback,
+					G_CALLBACK (fm_desktop_icon_view_trash_state_changed_callback),
 					desktop_icon_view,
-					GTK_OBJECT (desktop_icon_view));
+					G_OBJECT (desktop_icon_view));
 	
-	gtk_signal_connect_while_alive (GTK_OBJECT (nautilus_volume_monitor_get ()),
+	eel_signal_connect_while_alive (G_OBJECT (nautilus_volume_monitor_get ()),
 					"volume_mounted",
-					volume_mounted_callback,
+					G_CALLBACK (volume_mounted_callback),
 					desktop_icon_view,
-					GTK_OBJECT (desktop_icon_view));
+					G_OBJECT (desktop_icon_view));
 	
-	gtk_signal_connect_while_alive (GTK_OBJECT (nautilus_volume_monitor_get ()),
+	eel_signal_connect_while_alive (G_OBJECT (nautilus_volume_monitor_get ()),
 					"volume_unmounted",
-					volume_unmounted_callback,
+					G_CALLBACK (volume_unmounted_callback),
 					desktop_icon_view,
-					GTK_OBJECT (desktop_icon_view));
+					G_OBJECT (desktop_icon_view));
 	
 	eel_preferences_add_callback (NAUTILUS_PREFERENCES_HOME_URI,
-					   home_uri_changed,
-				  	   desktop_icon_view);
+				      home_uri_changed,
+				      desktop_icon_view);
 
 	/* Read out the panel desktop area and update the icon container
 	 * accordingly */
@@ -1046,8 +1042,7 @@ desktop_icons_compare_callback (NautilusIconContainer *container,
 	/* We know the answer, so prevent the other handlers
 	 * from overwriting our result.
 	 */
-	gtk_signal_emit_stop_by_name (GTK_OBJECT (container),
-				      "compare_icons");
+	g_signal_stop_emission_by_name (container, "compare_icons");
 	if (category_a < category_b) {
 		return -1;
 	} else {
@@ -1064,7 +1059,7 @@ mount_parameters_new (FMDesktopIconView *view, const char *mount_path)
 	g_assert (!eel_str_is_empty (mount_path)); 
 
 	new_parameters = g_new (MountParameters, 1);
-	gtk_object_ref (GTK_OBJECT (view));
+	g_object_ref (view);
 	new_parameters->view = view;
 	new_parameters->mount_path = g_strdup (mount_path);
 
@@ -1076,13 +1071,13 @@ mount_parameters_free (MountParameters *parameters)
 {
 	g_assert (parameters != NULL);
 
-	gtk_object_unref (GTK_OBJECT (parameters->view));
+	g_object_unref (parameters->view);
 	g_free (parameters->mount_path);
 	g_free (parameters);
 }
 
 static void
-mount_parameters_free_wrapper (gpointer user_data)
+mount_parameters_free_wrapper (gpointer user_data, GClosure *closure)
 {
 	mount_parameters_free ((MountParameters *)user_data);
 }
@@ -1159,13 +1154,11 @@ update_disks_menu (FMDesktopIconView *view)
 		g_free (command_path);
 
 		bonobo_ui_component_add_listener_full
-			(view->details->ui,
-			 command_name,
-			 mount_or_unmount_removable_volume,
-			 mount_parameters_new (view, nautilus_volume_get_mount_path (volume)),
-			 mount_parameters_free_wrapper);			 
+			(view->details->ui, command_name,
+			 g_cclosure_new (G_CALLBACK (mount_or_unmount_removable_volume),
+					 mount_parameters_new (view, nautilus_volume_get_mount_path (volume)),
+					 mount_parameters_free_wrapper));
 		g_free (command_name);
-		
 	}
 }
 
@@ -1242,6 +1235,7 @@ static void
 real_merge_menus (FMDirectoryView *view)
 {
 	FMDesktopIconView *desktop_view;
+	Bonobo_UIContainer ui_container;
 	BonoboUIVerb verbs [] = {
 		BONOBO_UI_VERB ("Change Background", change_background_callback),
 		BONOBO_UI_VERB ("Empty Trash Conditional", empty_trash_callback),
@@ -1256,12 +1250,15 @@ real_merge_menus (FMDirectoryView *view)
 	desktop_view = FM_DESKTOP_ICON_VIEW (view);
 
 	desktop_view->details->ui = bonobo_ui_component_new ("Desktop Icon View");
+
+	ui_container = fm_directory_view_get_bonobo_ui_container (view);
 	bonobo_ui_component_set_container (desktop_view->details->ui,
-					   fm_directory_view_get_bonobo_ui_container (view));
+					   ui_container, NULL);
+	bonobo_object_release_unref (ui_container, NULL);
 	bonobo_ui_util_set_ui (desktop_view->details->ui,
 			       DATADIR,
 			       "nautilus-desktop-icon-view-ui.xml",
-			       "nautilus");
+			       "nautilus", NULL);
 	bonobo_ui_component_add_verb_list_with_data (desktop_view->details->ui, verbs, view);
 }
 
