@@ -30,7 +30,6 @@
 #include <eel/eel-art-extensions.h>
 #include <eel/eel-art-gtk-extensions.h>
 #include <eel/eel-dnd.h>
-#include <eel/eel-gdk-font-extensions.h>
 #include <eel/eel-gdk-pixbuf-extensions.h>
 #include <eel/eel-glib-extensions.h>
 #include <eel/eel-gtk-extensions.h>
@@ -44,7 +43,6 @@
 #include <libgnomeui/gnome-uidefs.h>
 #include <libnautilus-private/nautilus-directory-background.h>
 #include <libnautilus-private/nautilus-file-dnd.h>
-#include <libnautilus-private/nautilus-font-factory.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
 #include <libnautilus-private/nautilus-metadata.h>
@@ -121,10 +119,10 @@ static GtkWidget *          fm_list_view_get_background_widget        (FMDirecto
 static void                 fm_list_view_clear                        (FMDirectoryView    *view);
 static GList *              fm_list_view_get_selection                (FMDirectoryView    *view);
 static NautilusZoomLevel    fm_list_view_get_zoom_level               (FMListView         *list_view);
-static void                 fm_list_view_initialize                   (gpointer            object,
+static void                 fm_list_view_init                   (gpointer            object,
 								       gpointer            klass);
-static void                 fm_list_view_initialize_class             (gpointer            klass);
-static void                 fm_list_view_destroy                      (GtkObject          *object);
+static void                 fm_list_view_class_init             (gpointer            klass);
+static void                 fm_list_view_finalize                      (GObject          *object);
 static void                 fm_list_view_end_file_changes             (FMDirectoryView    *view);
 static void                 fm_list_view_reset_to_defaults            (FMDirectoryView    *view);
 static void                 fm_list_view_select_all                   (FMDirectoryView    *view);
@@ -138,7 +136,6 @@ static void                 fm_list_view_set_zoom_level               (FMListVie
 static void                 fm_list_view_sort_items                   (FMListView         *list_view,
 								       int                 column,
 								       gboolean            reversed);
-static void                 fm_list_view_emblems_changed              (FMDirectoryView    *directory_view);
 static void                 fm_list_view_update_smooth_graphics_mode  (FMDirectoryView    *directory_view);
 static void                 fm_list_view_update_click_mode            (FMDirectoryView    *view);
 static void                 fm_list_view_embedded_text_policy_changed (FMDirectoryView    *view);
@@ -183,24 +180,22 @@ static void                 font_or_font_size_changed_callback        (gpointer
 static void                 default_sort_criteria_changed_callback    (gpointer            callback_data);
 static void                 default_zoom_level_changed_callback       (gpointer            callback_data);
 
-EEL_DEFINE_CLASS_BOILERPLATE (FMListView,
+EEL_CLASS_BOILERPLATE (FMListView,
 				   fm_list_view,
 				   FM_TYPE_DIRECTORY_VIEW)
 
 /* GtkObject methods.  */
 
 static void
-fm_list_view_initialize_class (gpointer klass)
+fm_list_view_class_init (gpointer klass)
 {
-	GtkObjectClass *object_class;
 	FMDirectoryViewClass *fm_directory_view_class;
 	FMListViewClass *fm_list_view_class;
 
-	object_class = GTK_OBJECT_CLASS (klass);
 	fm_directory_view_class = FM_DIRECTORY_VIEW_CLASS (klass);
 	fm_list_view_class = FM_LIST_VIEW_CLASS (klass);
 
-	object_class->destroy = fm_list_view_destroy;
+	G_OBJECT_CLASS (klass)->finalize = fm_list_view_finalize;
 
 	fm_directory_view_class->add_file = fm_list_view_add_file;
 	fm_directory_view_class->begin_file_changes = fm_list_view_begin_file_changes;
@@ -227,7 +222,6 @@ fm_list_view_initialize_class (gpointer klass)
         fm_directory_view_class->embedded_text_policy_changed = fm_list_view_embedded_text_policy_changed;
         fm_directory_view_class->image_display_policy_changed = fm_list_view_image_display_policy_changed;
         fm_directory_view_class->smooth_graphics_mode_changed = fm_list_view_update_smooth_graphics_mode;
-        fm_directory_view_class->emblems_changed = fm_list_view_emblems_changed;
         fm_directory_view_class->sort_directories_first_changed = real_sort_directories_first_changed;
 	fm_directory_view_class->remove_file = fm_list_view_remove_file;
 
@@ -246,7 +240,7 @@ fm_list_view_initialize_class (gpointer klass)
 }
 
 static void
-fm_list_view_initialize (gpointer object, gpointer klass)
+fm_list_view_init (gpointer object, gpointer klass)
 {
 	FMListView *list_view;
 	
@@ -266,29 +260,29 @@ fm_list_view_initialize (gpointer object, gpointer klass)
 	/* Register to find out about icon theme changes */
 	gtk_signal_connect_object_while_alive (nautilus_icon_factory_get (),
 					       "icons_changed",
-					       update_icons,
+					       G_CALLBACK (update_icons),
 					       GTK_OBJECT (list_view));	
 
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_LIST_VIEW_FONT,
-						       font_or_font_size_changed_callback, 
-						       list_view,
-						       GTK_OBJECT (list_view));
+						  font_or_font_size_changed_callback, 
+						  list_view,
+						  G_OBJECT (list_view));
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_SORT_ORDER,
-						       default_sort_criteria_changed_callback, 
-						       list_view,
-						       GTK_OBJECT (list_view));
+						  default_sort_criteria_changed_callback, 
+						  list_view,
+						  G_OBJECT (list_view));
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_ZOOM_LEVEL,
-						       default_zoom_level_changed_callback, 
-						       list_view,
-						       GTK_OBJECT (list_view));
+						  default_zoom_level_changed_callback, 
+						  list_view,
+						  G_OBJECT (list_view));
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_SORT_IN_REVERSE_ORDER,
-						       default_sort_criteria_changed_callback, 
-						       list_view,
-						       GTK_OBJECT (list_view));
+						  default_sort_criteria_changed_callback, 
+						  list_view,
+						  G_OBJECT (list_view));
 	eel_preferences_add_callback_while_alive (NAUTILUS_PREFERENCES_LIST_VIEW_DEFAULT_ZOOM_LEVEL_FONT_SIZE,
-						       font_or_font_size_changed_callback, 
-						       list_view,
-						       GTK_OBJECT (list_view));
+						  font_or_font_size_changed_callback, 
+						  list_view,
+						  G_OBJECT (list_view));
 	
 	/* It's important to not create the EelList (with a call
 	 * to create_list) until later, when the function pointers
@@ -304,10 +298,10 @@ fm_list_view_initialize (gpointer object, gpointer klass)
 }
 
 static void
-fm_list_view_destroy (GtkObject *object)
+fm_list_view_finalize (GObject *object)
 {
 	g_free (FM_LIST_VIEW (object)->details);
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 static void 
@@ -390,10 +384,10 @@ fm_list_view_compare_rows (EelCList *clist,
 	file2 = (NautilusFile *) (row2->data);
 
 	if (file1 == NULL) {
-		file1 = gtk_object_get_data (GTK_OBJECT (clist), PENDING_USER_DATA_KEY);
+		file1 = g_object_get_data (G_OBJECT (clist), PENDING_USER_DATA_KEY);
 	}
 	if (file2 == NULL) {
-		file2 = gtk_object_get_data (GTK_OBJECT (clist), PENDING_USER_DATA_KEY);
+		file2 = g_object_get_data (G_OBJECT (clist), PENDING_USER_DATA_KEY);
 	}
 	
 	list_view = FM_LIST_VIEW (GTK_WIDGET (clist)->parent);
@@ -405,13 +399,11 @@ fm_list_view_compare_rows (EelCList *clist,
  * folders-first and reversed-sort settings.
  */
 static int
-compare_rows_by_name (gconstpointer a, gconstpointer b, void *callback_data)
+compare_rows_by_name (gconstpointer a, gconstpointer b)
 {
 	EelCListRow *row1;
 	EelCListRow *row2;
 
-	g_assert (callback_data == NULL);
-
 	row1 = (EelCListRow *) a;
 	row2 = (EelCListRow *) b;
 
@@ -471,7 +463,7 @@ make_sorted_row_array (GtkWidget *widget)
 	array = eel_g_ptr_array_new_from_list (EEL_CLIST (widget)->row_list);
 
 	/* sort the array by the names of the NautilusFile objects */
-	eel_g_ptr_array_sort (array, compare_rows_by_name, NULL);
+	g_ptr_array_sort (array, compare_rows_by_name);
 
 	return array;
 }
@@ -506,7 +498,7 @@ select_matching_name_callback (GtkWidget *widget, const char *pattern, FMListVie
 	int array_row_index;
 
 	g_assert (EEL_IS_LIST (widget));
-	g_assert (gtk_object_get_data (GTK_OBJECT (widget), PENDING_USER_DATA_KEY) == NULL);
+	g_assert (g_object_get_data (G_OBJECT (widget), PENDING_USER_DATA_KEY) == NULL);
 		
 	/* build an array of rows, sorted by name */
 	array = make_sorted_row_array (widget);
@@ -535,7 +527,7 @@ select_previous_next_common (GtkWidget *widget, FMListView *list_view, gboolean
 	int last_selected_row;
 
 	g_assert (EEL_IS_LIST (widget));
-	g_assert (gtk_object_get_data (GTK_OBJECT (widget), PENDING_USER_DATA_KEY) == NULL);
+	g_assert (g_object_get_data (G_OBJECT (widget), PENDING_USER_DATA_KEY) == NULL);
 
 	/* build an array of rows */
 	array = make_sorted_row_array (widget);
@@ -543,7 +535,7 @@ select_previous_next_common (GtkWidget *widget, FMListView *list_view, gboolean
 		return;
 
 	/* sort the array by the names of the NautilusFile objects */
-	eel_g_ptr_array_sort (array, compare_rows_by_name, NULL);
+	g_ptr_array_sort (array, compare_rows_by_name);
 
 	/* find the index of the first and the last selected row */
 	first_selected_row = -1;
@@ -976,15 +968,6 @@ fm_list_view_update_smooth_graphics_mode (FMDirectoryView *directory_view)
 	}
 }
 
-static void
-fm_list_view_emblems_changed (FMDirectoryView *directory_view)
-{
-	g_assert (FM_IS_LIST_VIEW (directory_view));
-	
-	update_icons (FM_LIST_VIEW (directory_view));
-}
-
-
 static void
 real_sort_directories_first_changed (FMDirectoryView *directory_view)
 {
@@ -1065,8 +1048,9 @@ fm_list_view_update_font (FMListView *list_view)
 	char *font_name;
 	int standard_font_size;
 	int font_size;
-
+#if GNOME2_CONVERSION_COMPLETE
 	GdkFont *font;
+#endif
 
 	g_return_if_fail (FM_IS_LIST_VIEW (list_view));
 
@@ -1075,10 +1059,12 @@ fm_list_view_update_font (FMListView *list_view)
 	
 	font_size = standard_font_size + font_size_delta_table[list_view->details->zoom_level];
 
+#if GNOME2_CONVERSION_COMPLETE
 	font = nautilus_font_factory_get_font_by_family (font_name, font_size);
 	g_assert (font != NULL);
 	eel_gtk_widget_set_font (GTK_WIDGET (get_list (list_view)), font);
 	gdk_font_unref (font);
+#endif
 	g_free (font_name);
 }
 
@@ -1099,7 +1085,11 @@ measure_width_callback (const char *string, void *context)
 static char *
 truncate_middle_callback (const char *string, int width, void *context)
 {
+#if GNOME2_CONVERSION_COMPLETE	
 	return eel_string_ellipsize (string, (GdkFont *)context, width, EEL_ELLIPSIZE_MIDDLE);
+#else
+	return g_strdup (string);
+#endif
 }
 
 static char *
@@ -1136,8 +1126,12 @@ get_cell_text (GtkWidget *widget, int column_index, int cell_width,
 		cell_text = NULL;
 		break;
 	}
-		
+	
+#if GNOME2_CONVERSION_COMPLETE	
 	return eel_string_ellipsize (cell_text, font, cell_width, EEL_ELLIPSIZE_MIDDLE);
+#else
+	return g_strdup (cell_text);
+#endif
 }
 
 
@@ -1152,65 +1146,65 @@ set_up_list (FMListView *list_view)
 
 	GTK_WIDGET_SET_FLAGS (list, GTK_CAN_FOCUS);
 
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "activate",
-			    GTK_SIGNAL_FUNC (list_activate_callback),
+			    G_CALLBACK (list_activate_callback),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "selection_changed",
-			    GTK_SIGNAL_FUNC (list_selection_changed_callback),
+			    G_CALLBACK (list_selection_changed_callback),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "click_column",
-			    column_clicked_callback,
+			    G_CALLBACK (column_clicked_callback),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "context_click_selection",
-			    context_click_selection_callback,
+			    G_CALLBACK (context_click_selection_callback),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "context_click_background",
-			    context_click_background_callback,
+			    G_CALLBACK (context_click_background_callback),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "select_matching_name",
-			    select_matching_name_callback,
+			    G_CALLBACK (select_matching_name_callback),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "select_previous_name",
-			    select_previous_name_callback,
+			    G_CALLBACK (select_previous_name_callback),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "select_next_name",
-			    select_next_name_callback,
+			    G_CALLBACK (select_next_name_callback),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "handle_dragged_items",
-			    GTK_SIGNAL_FUNC(fm_list_handle_dragged_items),
+			    G_CALLBACK (fm_list_handle_dragged_items),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "handle_dropped_items",
-			    fm_list_handle_dropped_items,
+			    G_CALLBACK (fm_list_handle_dropped_items),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "get_default_action",
-			    fm_list_get_default_action,
+			    G_CALLBACK (fm_list_get_default_action),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "drag_data_get",
-			    fm_list_drag_data_get,
+			    G_CALLBACK (fm_list_drag_data_get),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "get_drag_pixbuf",
-			    GTK_SIGNAL_FUNC (fm_list_get_drag_pixbuf),
+			    G_CALLBACK (fm_list_get_drag_pixbuf),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "get_sort_column_index",
-			    GTK_SIGNAL_FUNC (fm_list_get_sort_column_index),
+			    G_CALLBACK (fm_list_get_sort_column_index),
 			    list_view);
-	gtk_signal_connect (GTK_OBJECT (list),
+	g_signal_connect (list,
 			    "get_cell_text",
-			    GTK_SIGNAL_FUNC (get_cell_text),
+			    G_CALLBACK (get_cell_text),
 			    list_view);	
 
 	/* Make height tall enough for icons to look good.
@@ -1219,9 +1213,9 @@ set_up_list (FMListView *list_view)
 	 * the "realize" signal is slightly too early, so we connect to
 	 * "map".
 	 */
-	gtk_signal_connect (GTK_OBJECT (list_view),
+	g_signal_connect (list_view,
 			    "map",
-			    fm_list_view_reset_row_height,
+			    G_CALLBACK (fm_list_view_reset_row_height),
 			    NULL);
 
 	fm_list_view_update_click_mode (FM_DIRECTORY_VIEW (list_view));
@@ -1297,12 +1291,12 @@ add_to_list (FMListView *list_view, NautilusFile *file)
 	/* Temporarily set user data value as hack for the problem
 	 * that compare_rows is called before the row data can be set.
 	 */
-	gtk_object_set_data (GTK_OBJECT (clist), PENDING_USER_DATA_KEY, file);
+	g_object_set_data (G_OBJECT (clist), PENDING_USER_DATA_KEY, file);
 	/* Note that since list is auto-sorted new_row isn't necessarily last row. */
 	new_row = eel_clist_append (clist, text);
 
 	eel_clist_set_row_data (clist, new_row, file);
-	gtk_object_set_data (GTK_OBJECT (clist), PENDING_USER_DATA_KEY, NULL);
+	g_object_set_data (G_OBJECT (clist), PENDING_USER_DATA_KEY, NULL);
 
 	/* Mark one column as a link. */
 	eel_list_mark_cell_as_link (list, new_row, get_link_column (list_view));
@@ -1840,7 +1834,7 @@ fm_list_view_sort_files (FMDirectoryView *view,
 	/* Sort the added items before displaying them, so that
 	 * they'll be added in order, and items won't move around.
 	 */
-	*files = eel_g_list_sort_custom (*files, list_view_compare_files_for_sort, view);
+	*files = g_list_sort_with_data (*files, list_view_compare_files_for_sort, view);
 }
 
 static GArray *
