@@ -39,6 +39,7 @@
 #include <eel/eel-vfs-extensions.h>
 #include <eel/eel-viewport.h>
 #include <eel/eel-wrap-table.h>
+#include <gtk/gtkalignment.h>
 #include <gtk/gtkcheckbutton.h>
 #include <gtk/gtkdnd.h>
 #include <gtk/gtkentry.h>
@@ -49,12 +50,10 @@
 #include <gtk/gtkmain.h>
 #include <gtk/gtknotebook.h>
 #include <gtk/gtkoptionmenu.h>
-#include <gtk/gtkpixmap.h>
 #include <gtk/gtkscrolledwindow.h>
 #include <gtk/gtksignal.h>
 #include <gtk/gtktable.h>
 #include <gtk/gtkvbox.h>
-#include <libgnome/gnome-defs.h>
 #include <libgnome/gnome-i18n.h>
 #include <libgnomeui/gnome-dialog.h>
 #include <libgnomeui/gnome-uidefs.h>
@@ -148,10 +147,9 @@ static GtkTargetEntry target_table[] = {
 #define EMBLEM_LABEL_SPACING			2
 
 static void real_destroy                          (GtkObject               *object);
-static void real_finalize                         (GtkObject               *object);
-static void real_shutdown                         (GtkObject               *object);
-static void fm_properties_window_initialize_class (FMPropertiesWindowClass *class);
-static void fm_properties_window_initialize       (FMPropertiesWindow      *window);
+static void real_finalize                         (GObject                 *object);
+static void fm_properties_window_class_init       (FMPropertiesWindowClass *class);
+static void fm_properties_window_init             (FMPropertiesWindow      *window);
 static void create_properties_window_callback     (NautilusFile		   *file,
 						   gpointer                 data);
 static void cancel_group_change_callback          (gpointer                 callback_data);
@@ -169,22 +167,18 @@ static void remove_pending_file                   (StartupData             *data
 						   gboolean                 cancel_timed_wait,
 						   gboolean                 cancel_destroy_handler);
 
-EEL_DEFINE_CLASS_BOILERPLATE (FMPropertiesWindow, fm_properties_window, GTK_TYPE_WINDOW)
+EEL_CLASS_BOILERPLATE (FMPropertiesWindow, fm_properties_window, GTK_TYPE_WINDOW)
 
 static void
-fm_properties_window_initialize_class (FMPropertiesWindowClass *class)
+fm_properties_window_class_init (FMPropertiesWindowClass *class)
 {
-	GtkObjectClass *object_class;
-
-	object_class = GTK_OBJECT_CLASS (class);
+	G_OBJECT_CLASS (class)->finalize = real_finalize;
 	
-	object_class->destroy = real_destroy;
-	object_class->shutdown = real_shutdown;
-	object_class->finalize = real_finalize;
+	GTK_OBJECT_CLASS (class)->destroy = real_destroy;
 }
 
 static void
-fm_properties_window_initialize (FMPropertiesWindow *window)
+fm_properties_window_init (FMPropertiesWindow *window)
 {
 	window->details = g_new0 (FMPropertiesWindowDetails, 1);
 
@@ -263,7 +257,7 @@ update_properties_window_icon (EelImage *image)
 
 	g_assert (EEL_IS_IMAGE (image));
 
-	file = gtk_object_get_data (GTK_OBJECT (image), "nautilus_file");
+	file = g_object_get_data (G_OBJECT (image), "nautilus_file");
 
 	g_assert (NAUTILUS_IS_FILE (file));
 	
@@ -271,7 +265,7 @@ update_properties_window_icon (EelImage *image)
 
 	eel_image_set_pixbuf (image, pixbuf);
 	
-	gdk_pixbuf_unref (pixbuf);
+	g_object_unref (pixbuf);
 }
 
 
@@ -287,13 +281,13 @@ uri_is_local_image (const char *uri)
 		return FALSE;
 	}
 
-	pixbuf = gdk_pixbuf_new_from_file (image_path);
+	pixbuf = gdk_pixbuf_new_from_file (image_path, NULL);
 	g_free (image_path);
 	
 	if (pixbuf == NULL) {
 		return FALSE;
 	}
-	gdk_pixbuf_unref (pixbuf);
+	g_object_unref (pixbuf);
 	return TRUE;
 }
 
@@ -358,33 +352,33 @@ create_image_widget_for_file (NautilusFile *file)
 	/* prepare the image to receive dropped objects to assign custom images */
 	gtk_drag_dest_set (GTK_WIDGET (image),
 			   GTK_DEST_DEFAULT_MOTION | GTK_DEST_DEFAULT_HIGHLIGHT | GTK_DEST_DEFAULT_DROP, 
-			   target_table, EEL_N_ELEMENTS (target_table),
+			   target_table, G_N_ELEMENTS (target_table),
 			   GDK_ACTION_COPY | GDK_ACTION_MOVE);
 
 	gtk_signal_connect( GTK_OBJECT (image), "drag_data_received",
-			    GTK_SIGNAL_FUNC (fm_properties_window_drag_data_received), NULL);
+			    G_CALLBACK (fm_properties_window_drag_data_received), NULL);
 
 
 	eel_image_set_pixbuf (EEL_IMAGE (image), pixbuf);
 
-	gdk_pixbuf_unref (pixbuf);
+	g_object_unref (pixbuf);
 
 	nautilus_file_ref (file);
-	gtk_object_set_data_full (GTK_OBJECT (image),
-				  "nautilus_file",
-				  file,
-				  (GtkDestroyNotify) nautilus_file_unref);
+	g_object_set_data_full (G_OBJECT (image),
+				"nautilus_file",
+				file,
+				(GtkDestroyNotify) nautilus_file_unref);
 
 	/* React to icon theme changes. */
 	gtk_signal_connect_object_while_alive (nautilus_icon_factory_get (),
 					       "icons_changed",
-					       update_properties_window_icon,
+					       G_CALLBACK (update_properties_window_icon),
 					       GTK_OBJECT (image));
 
 	/* Name changes can also change icon (since name is determined by MIME type) */
 	gtk_signal_connect_object_while_alive (GTK_OBJECT (file),
 					       "changed",
-					       update_properties_window_icon,
+					       G_CALLBACK (update_properties_window_icon),
 					       GTK_OBJECT (image));
 	return image;
 }
@@ -396,7 +390,7 @@ name_field_update_to_match_file (NautilusEntry *name_field)
 	const char *original_name;
 	char *current_name, *displayed_name;
 
-	file = gtk_object_get_data (GTK_OBJECT (name_field), "nautilus_file");
+	file = g_object_get_data (G_OBJECT (name_field), "nautilus_file");
 
 	if (file == NULL || nautilus_file_is_gone (file)) {
 		gtk_widget_set_sensitive (GTK_WIDGET (name_field), FALSE);
@@ -404,7 +398,7 @@ name_field_update_to_match_file (NautilusEntry *name_field)
 		return;
 	}
 
-	original_name = (const char *) gtk_object_get_data (GTK_OBJECT (name_field),
+	original_name = (const char *) g_object_get_data (G_OBJECT (name_field),
 						      	    "original_name");
 
 	/* If the file name has changed since the original name was stored,
@@ -414,10 +408,10 @@ name_field_update_to_match_file (NautilusEntry *name_field)
 	 */
 	current_name = nautilus_file_get_display_name (file);
 	if (eel_strcmp (original_name, current_name) != 0) {
-		gtk_object_set_data_full (GTK_OBJECT (name_field),
-					  "original_name",
-					  current_name,
-					  g_free);
+		g_object_set_data_full (G_OBJECT (name_field),
+					"original_name",
+					current_name,
+					g_free);
 
 		/* Only reset the text if it's different from what is
 		 * currently showing. This causes minimal ripples (e.g.
@@ -449,8 +443,8 @@ name_field_restore_original_name (NautilusEntry *name_field)
 	const char *original_name;
 	char *displayed_name;
 
-	original_name = (const char *) gtk_object_get_data (GTK_OBJECT (name_field),
-						      	    "original_name");
+	original_name = (const char *) g_object_get_data (G_OBJECT (name_field),
+							  "original_name");
 	displayed_name = gtk_editable_get_chars (GTK_EDITABLE (name_field), 0, -1);
 
 	if (strcmp (original_name, displayed_name) != 0) {
@@ -476,13 +470,12 @@ rename_callback (NautilusFile *file, GnomeVFSResult result, gpointer callback_da
 					       window->details->pending_name, 
 					       result,
 					       GTK_WINDOW (window));
-		/* This can trigger after window destroy, before finalize. */
-		if (!GTK_OBJECT_DESTROYED (window)) {
+		if (window->details->name_field != NULL) {
 			name_field_restore_original_name (window->details->name_field);
 		}
 	}
 
-	gtk_object_unref (GTK_OBJECT (window));
+	g_object_unref (window);
 }
 
 static void
@@ -500,7 +493,7 @@ name_field_done_editing (NautilusEntry *name_field, FMPropertiesWindow *window)
 	
 	g_assert (NAUTILUS_IS_ENTRY (name_field));
 
-	file = gtk_object_get_data (GTK_OBJECT (name_field), "nautilus_file");
+	file = g_object_get_data (G_OBJECT (name_field), "nautilus_file");
 
 	g_assert (NAUTILUS_IS_FILE (file));
 
@@ -518,7 +511,7 @@ name_field_done_editing (NautilusEntry *name_field, FMPropertiesWindow *window)
 		name_field_restore_original_name (NAUTILUS_ENTRY (name_field));
 	} else {
 		set_pending_name (window, new_name);
-		gtk_object_ref (GTK_OBJECT (window));
+		g_object_ref (window);
 		nautilus_file_rename (file, new_name,
 				      rename_callback, window);
 	}
@@ -559,8 +552,8 @@ property_button_update (GtkToggleButton *button)
 	char *name;
 	GList *keywords, *word;
 
-	file = gtk_object_get_data (GTK_OBJECT (button), "nautilus_file");
-	name = gtk_object_get_data (GTK_OBJECT (button), "nautilus_property_name");
+	file = g_object_get_data (G_OBJECT (button), "nautilus_file");
+	name = g_object_get_data (G_OBJECT (button), "nautilus_property_name");
 
 	/* Handle the case where there's nothing to toggle. */
 	if (file == NULL || nautilus_file_is_gone (file) || name == NULL) {
@@ -582,8 +575,8 @@ property_button_toggled (GtkToggleButton *button)
 	char *name;
 	GList *keywords, *word;
 
-	file = gtk_object_get_data (GTK_OBJECT (button), "nautilus_file");
-	name = gtk_object_get_data (GTK_OBJECT (button), "nautilus_property_name");
+	file = g_object_get_data (G_OBJECT (button), "nautilus_file");
+	name = g_object_get_data (G_OBJECT (button), "nautilus_property_name");
 
 	/* Handle the case where there's nothing to toggle. */
 	if (file == NULL || nautilus_file_is_gone (file) || name == NULL) {
@@ -648,7 +641,7 @@ value_field_update_internal (GtkLabel *label,
 	g_assert (NAUTILUS_IS_FILE (file));
 	g_assert (!ellipsize_text || EEL_IS_ELLIPSIZING_LABEL (label));
 
-	attribute_name = gtk_object_get_data (GTK_OBJECT (label), "file_attribute");
+	attribute_name = g_object_get_data (G_OBJECT (label), "file_attribute");
 	attribute_value = nautilus_file_get_string_attribute_with_default (file, attribute_name);
 
 	if (ellipsize_text) {
@@ -739,10 +732,10 @@ attach_value_field_internal (GtkTable *table,
 	}
 
 	/* Stash a copy of the file attribute name in this field for the callback's sake. */
-	gtk_object_set_data_full (GTK_OBJECT (value_field),
-				  "file_attribute",
-				  g_strdup (file_attribute_name),
-				  g_free);
+	g_object_set_data_full (G_OBJECT (value_field),
+				"file_attribute",
+				g_strdup (file_attribute_name),
+				g_free);
 
 	/* Fill in the value. */
 	if (ellipsize_text) {
@@ -755,8 +748,8 @@ attach_value_field_internal (GtkTable *table,
 	gtk_signal_connect_object_while_alive (GTK_OBJECT (file),
 					       "changed",
 					       ellipsize_text
-					           ? ellipsizing_value_field_update
-					           : value_field_update,
+					       ? G_CALLBACK (ellipsizing_value_field_update)
+					       : G_CALLBACK (value_field_update),
 					       GTK_OBJECT (value_field));	
 }			     
 
@@ -831,10 +824,10 @@ create_group_menu_item (NautilusFile *file, const char *group_name)
 	gtk_widget_show (menu_item);
 
 	eel_gtk_signal_connect_free_data_custom (GTK_OBJECT (menu_item),
-			    		       	      "activate",
-			    		       	      activate_group_callback,
-			    		       	      file_name_pair_new (file, group_name),
-			    		       	      (GtkDestroyNotify)file_name_pair_free);
+						 "activate",
+						 G_CALLBACK (activate_group_callback),
+						 file_name_pair_new (file, group_name),
+						 (GtkDestroyNotify)file_name_pair_free);
 
 	return menu_item;
 }
@@ -935,7 +928,7 @@ attach_group_menu (GtkTable *table,
 	/* Connect to signal to update menu when file changes. */
 	gtk_signal_connect_object_while_alive (GTK_OBJECT (file),
 					       "changed",
-					       synch_groups_menu,
+					       G_CALLBACK (synch_groups_menu),
 					       GTK_OBJECT (option_menu));	
 }	
 
@@ -1004,10 +997,10 @@ create_owner_menu_item (NautilusFile *file, const char *user_name)
 	gtk_widget_show (menu_item);
 
 	eel_gtk_signal_connect_free_data_custom (GTK_OBJECT (menu_item),
-			    		       	      "activate",
-			    		       	      activate_owner_callback,
-			    		       	      file_name_pair_new (file, name_array[0]),
-			    		       	      (GtkDestroyNotify)file_name_pair_free);
+						 "activate",
+						 G_CALLBACK (activate_owner_callback),
+						 file_name_pair_new (file, name_array[0]),
+						 (GtkDestroyNotify)file_name_pair_free);
 	g_strfreev (name_array);
 	return menu_item;
 }
@@ -1082,7 +1075,7 @@ attach_owner_menu (GtkTable *table,
 	/* Connect to signal to update menu when file changes. */
 	gtk_signal_connect_object_while_alive (GTK_OBJECT (file),
 					       "changed",
-					       synch_user_menu,
+					       G_CALLBACK (synch_user_menu),
 					       GTK_OBJECT (option_menu));	
 }
 
@@ -1253,7 +1246,7 @@ attach_directory_contents_value_field (FMPropertiesWindow *window,
 	/* Connect to signal to update value when file changes. */
 	gtk_signal_connect_object_while_alive (GTK_OBJECT (window->details->target_file),
 					       "updated_deep_count_in_progress",
-					       schedule_directory_contents_update,
+					       G_CALLBACK (schedule_directory_contents_update),
 					       GTK_OBJECT (window));
 
 	return value_field;	
@@ -1381,7 +1374,7 @@ append_directory_contents_fields (FMPropertiesWindow *window,
 		(NAUTILUS_PREFERENCES_SHOW_DIRECTORY_ITEM_COUNTS,
 		 update_visibility_of_item_count_fields_wrapper,
 		 window,
-		 GTK_OBJECT (window));
+		 G_OBJECT (window));
 	
 	return last_row;
 }
@@ -1573,10 +1566,10 @@ create_basic_page (FMPropertiesWindow *window)
 				   
 	/* Attach parameters and signal handler. */
 	nautilus_file_ref (original_file);
-	gtk_object_set_data_full (GTK_OBJECT (name_field),
-				  "nautilus_file",
-				  original_file,
-				  (GtkDestroyNotify) nautilus_file_unref);
+	g_object_set_data_full (G_OBJECT (name_field),
+				"nautilus_file",
+				original_file,
+				(GtkDestroyNotify) nautilus_file_unref);
 
 	/* Update name field initially before hooking up changed signal. */
 	name_field_update_to_match_file (NAUTILUS_ENTRY (name_field));
@@ -1595,12 +1588,12 @@ create_basic_page (FMPropertiesWindow *window)
 	nautilus_undo_editable_set_undo_key (GTK_EDITABLE (name_field), TRUE);
 #endif
 
-	gtk_signal_connect (GTK_OBJECT (name_field), "focus_out_event",
-      	              	    GTK_SIGNAL_FUNC (name_field_focus_out),
+	g_signal_connect (name_field, "focus_out_event",
+      	              	    G_CALLBACK (name_field_focus_out),
                             window);
                       			    
-	gtk_signal_connect (GTK_OBJECT (name_field), "activate",
-      	              	    name_field_activate,
+	g_signal_connect (name_field, "activate",
+      	              	    G_CALLBACK (name_field_activate),
                             window);
 
         /* Start with name field selected, if it's sensitive. */
@@ -1612,7 +1605,7 @@ create_basic_page (FMPropertiesWindow *window)
 	/* React to name changes from elsewhere. */
 	gtk_signal_connect_object_while_alive (GTK_OBJECT (target_file),
 					       "changed",
-					       name_field_update_to_match_file,
+					       G_CALLBACK (name_field_update_to_match_file),
 					       GTK_OBJECT (name_field));
 
 	if (should_show_file_type (window)) {
@@ -1646,17 +1639,17 @@ create_basic_page (FMPropertiesWindow *window)
 		gtk_widget_show (button_box);
 		gtk_box_pack_end (GTK_BOX(container), button_box, FALSE, FALSE, 4);  
 		
-	 	temp_button = gtk_button_new_with_label (_("Select Custom Icon..."));
+	 	temp_button = gtk_button_new_with_mnemonic (_("_Select Custom Icon..."));
 		gtk_widget_show (temp_button);
 		gtk_box_pack_start (GTK_BOX (button_box), temp_button, FALSE, FALSE, 4);  
-		eel_gtk_button_set_standard_padding (GTK_BUTTON (temp_button));
-		gtk_signal_connect(GTK_OBJECT (temp_button), "clicked", GTK_SIGNAL_FUNC (select_image_button_callback), window);
+
+		gtk_signal_connect(GTK_OBJECT (temp_button), "clicked", G_CALLBACK (select_image_button_callback), window);
 	 	
-	 	temp_button = gtk_button_new_with_label (_("Remove Custom Icon"));
+	 	temp_button = gtk_button_new_with_mnemonic (_("_Remove Custom Icon"));
 		gtk_widget_show (temp_button);
 		gtk_box_pack_start (GTK_BOX(button_box), temp_button, FALSE, FALSE, 4);  
-		eel_gtk_button_set_standard_padding (GTK_BUTTON (temp_button));
-	 	gtk_signal_connect (GTK_OBJECT (temp_button), "clicked", GTK_SIGNAL_FUNC (remove_image_button_callback), window);
+
+	 	g_signal_connect (temp_button, "clicked", G_CALLBACK (remove_image_button_callback), window);
 
 		window->details->remove_image_button = temp_button;
 		
@@ -1708,10 +1701,10 @@ create_emblems_page (FMPropertiesWindow *window)
 	 * This must be done after the widget is realized, due to
 	 * an apparent bug in gtk_viewport_set_shadow_type.
 	 */
-	gtk_signal_connect (GTK_OBJECT (GTK_BIN (scroller)->child), 
-			    "realize", 
-			    remove_default_viewport_shadow, 
-			    NULL);
+	g_signal_connect (GTK_BIN (scroller)->child, 
+			  "realize", 
+			  G_CALLBACK (remove_default_viewport_shadow),
+			  NULL);
 
 	gtk_notebook_append_page (window->details->notebook, 
 				  scroller, gtk_label_new (_("Emblems")));
@@ -1733,7 +1726,7 @@ create_emblems_page (FMPropertiesWindow *window)
 		}
 		
 		if (strcmp (emblem_name, "erase") == 0) {
-			gdk_pixbuf_unref (pixbuf);
+			g_object_unref (pixbuf);
 			g_free (label);
 			g_free (emblem_name);
 			continue;
@@ -1744,23 +1737,23 @@ create_emblems_page (FMPropertiesWindow *window)
 		eel_labeled_image_set_spacing (EEL_LABELED_IMAGE (GTK_BIN (button)->child), EMBLEM_LABEL_SPACING);
 		
 		g_free (label);
-		gdk_pixbuf_unref (pixbuf);
+		g_object_unref (pixbuf);
 
 		/* Attach parameters and signal handler. */
-		gtk_object_set_data_full (GTK_OBJECT (button),
-					  "nautilus_property_name",
-					  emblem_name,
-					  g_free);
+		g_object_set_data_full (G_OBJECT (button),
+					"nautilus_property_name",
+					emblem_name,
+					g_free);
 				     
 		nautilus_file_ref (file);
-		gtk_object_set_data_full (GTK_OBJECT (button),
-					  "nautilus_file",
-					  file,
-					  (GtkDestroyNotify) nautilus_file_unref);
+		g_object_set_data_full (G_OBJECT (button),
+					"nautilus_file",
+					file,
+					(GtkDestroyNotify) nautilus_file_unref);
 		
-		gtk_signal_connect (GTK_OBJECT (button),
+		g_signal_connect (button,
 				    "toggled",
-				    property_button_toggled,
+				    G_CALLBACK (property_button_toggled),
 				    NULL);
 
 		/* Set initial state of button. */
@@ -1769,7 +1762,7 @@ create_emblems_page (FMPropertiesWindow *window)
 		/* Update button when file changes in future. */
 		gtk_signal_connect_object_while_alive (GTK_OBJECT (file),
 						       "changed",
-						       property_button_update,
+						       G_CALLBACK (property_button_update),
 						       GTK_OBJECT (button));
 
 		gtk_container_add (GTK_CONTAINER (emblems_table), button);
@@ -1814,9 +1807,9 @@ update_permissions_check_button_state (GtkWidget *check_button, NautilusFile *fi
 	
 	g_assert (nautilus_file_can_get_permissions (file));
 
-	toggled_signal_id = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (check_button),
+	toggled_signal_id = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (check_button),
 						 		  "toggled_signal_id"));
-	permission = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (check_button),
+	permission = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (check_button),
 							   "permission"));
 	g_assert (toggled_signal_id > 0);
 	g_assert (permission != 0);
@@ -1855,7 +1848,7 @@ permissions_check_button_toggled (GtkToggleButton *toggle_button, gpointer user_
 	g_assert (nautilus_file_can_get_permissions (file));
 	g_assert (nautilus_file_can_set_permissions (file));
 
-	permission_mask = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (toggle_button),
+	permission_mask = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (toggle_button),
 					  "permission"));
 
 	/* Modify the file's permissions according to the state of this check button. */
@@ -1881,15 +1874,15 @@ set_up_permissions_checkbox (GtkWidget *check_button,
 {
 	guint toggled_signal_id;
 
-	toggled_signal_id = gtk_signal_connect (GTK_OBJECT (check_button), "toggled",
-      	              	    			GTK_SIGNAL_FUNC (permissions_check_button_toggled),
+	toggled_signal_id = g_signal_connect (check_button, "toggled",
+      	              	    			G_CALLBACK (permissions_check_button_toggled),
                             			file);
 
 	/* Load up the check_button with data we'll need when updating its state. */
-        gtk_object_set_data (GTK_OBJECT (check_button), 
+        g_object_set_data (G_OBJECT (check_button), 
         		     "toggled_signal_id", 
         		     GINT_TO_POINTER (toggled_signal_id));
-        gtk_object_set_data (GTK_OBJECT (check_button), 
+        g_object_set_data (G_OBJECT (check_button), 
         		     "permission", 
         		     GINT_TO_POINTER (permission));
 	
@@ -1899,7 +1892,7 @@ set_up_permissions_checkbox (GtkWidget *check_button,
         /* Update state later if file changes. */
 	gtk_signal_connect_object_while_alive (GTK_OBJECT (file),
 					       "changed",
-					       update_permissions_check_button_state,
+					       G_CALLBACK (update_permissions_check_button_state),
 					       GTK_OBJECT (check_button));
 }
 
@@ -2000,7 +1993,7 @@ append_special_execution_flags (FMPropertiesWindow *window,
 		(NAUTILUS_PREFERENCES_SHOW_SPECIAL_FLAGS,
 		 update_visibility_of_special_flags_widgets_wrapper,
 		 window,
-		 GTK_OBJECT (window));
+		 G_OBJECT (window));
 	
 }
 
@@ -2248,7 +2241,7 @@ create_properties_window (StartupData *startup_data)
 	window->details->file_changed_handler_id =
 		gtk_signal_connect_object (GTK_OBJECT (window->details->target_file),
 					   "changed",
-					   properties_window_file_changed_callback,
+					   G_CALLBACK (properties_window_file_changed_callback),
 					   GTK_OBJECT (window));
 
 	/* Create the notebook tabs. */
@@ -2370,7 +2363,7 @@ remove_pending_file (StartupData *startup_data,
 	}
 	if (cancel_destroy_handler) {
 		gtk_signal_disconnect_by_func (GTK_OBJECT (startup_data->directory_view),
-					       directory_view_destroyed_callback,
+					       G_CALLBACK (directory_view_destroyed_callback),
 					       startup_data);
 	}
 	g_hash_table_remove (pending_files, startup_data->original_file);
@@ -2421,9 +2414,9 @@ fm_properties_window_present (NautilusFile *original_file, FMDirectoryView *dire
 	 */
 	
 	g_hash_table_insert (pending_files, target_file, target_file);
-	gtk_signal_connect (GTK_OBJECT (directory_view),
+	g_signal_connect (directory_view,
 			    "destroy",
-			    directory_view_destroyed_callback,
+			    G_CALLBACK (directory_view_destroyed_callback),
 			    startup_data);
 
 	parent_window = gtk_widget_get_ancestor (GTK_WIDGET (directory_view), GTK_TYPE_WINDOW);
@@ -2441,22 +2434,6 @@ fm_properties_window_present (NautilusFile *original_file, FMDirectoryView *dire
 		 create_properties_window_callback, startup_data);
 }
 
-static void
-real_shutdown (GtkObject *object)
-{
-	FMPropertiesWindow *window;
-
-	window = FM_PROPERTIES_WINDOW (object);
-
-	/* Disconnect file-changed handler here to avoid infinite loop
-	 * of change notifications when file is removed; see bug 4911.
-	 */
-	gtk_signal_disconnect (GTK_OBJECT (window->details->target_file), 
-			       window->details->file_changed_handler_id);
-
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, shutdown, (object));
-}
-
 static void
 real_destroy (GtkObject *object)
 {
@@ -2465,39 +2442,48 @@ real_destroy (GtkObject *object)
 	window = FM_PROPERTIES_WINDOW (object);
 
 	g_hash_table_remove (windows, window->details->original_file);
+	
+	if (window->details->original_file != NULL) {
+		nautilus_file_monitor_remove (window->details->original_file, window);
+		nautilus_file_unref (window->details->original_file);
+		window->details->original_file = NULL;
+	}
 
-	nautilus_file_monitor_remove (window->details->original_file, window);
-	nautilus_file_unref (window->details->original_file);
+	if (window->details->target_file != NULL) {
+		gtk_signal_disconnect (GTK_OBJECT (window->details->target_file), 
+				       window->details->file_changed_handler_id);
+		nautilus_file_monitor_remove (window->details->target_file, window);
+		nautilus_file_unref (window->details->target_file);
+		window->details->target_file = NULL;
+	}
 
-	nautilus_file_monitor_remove (window->details->target_file, window);
-	nautilus_file_unref (window->details->target_file);	
+	window->details->name_field = NULL;
 	
 	g_list_free (window->details->directory_contents_widgets);
+	window->details->directory_contents_widgets = NULL;
+
 	g_list_free (window->details->special_flags_widgets);
+	window->details->special_flags_widgets = NULL;
 
 	if (window->details->update_directory_contents_timeout_id != 0) {
 		gtk_timeout_remove (window->details->update_directory_contents_timeout_id);
+		window->details->update_directory_contents_timeout_id = 0;
 	}
 
-
-	/* Note that file_changed_handler_id is disconnected in shutdown,
-	 * and details are freed in finalize 
-	 */
 	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void
-real_finalize (GtkObject *object)
+real_finalize (GObject *object)
 {
 	FMPropertiesWindow *window;
 
 	window = FM_PROPERTIES_WINDOW (object);
 
-	/* Note that file_changed_handler_id is disconnected in shutdown */
 	g_free (window->details->pending_name);
 	g_free (window->details);
 
-	EEL_CALL_PARENT (GTK_OBJECT_CLASS, finalize, (object));
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 /* icon selection callback to set the image of the file object to the selected file */
@@ -2527,6 +2513,7 @@ set_icon_callback (const char* icon_path, FMPropertiesWindow *properties_window)
 static void
 select_image_button_callback (GtkWidget *widget, FMPropertiesWindow *properties_window)
 {
+#if GNOME2_CONVERSION_COMPLETE
 	GtkWidget *dialog;
 
 	g_assert (FM_IS_PROPERTIES_WINDOW (properties_window));
@@ -2536,6 +2523,7 @@ select_image_button_callback (GtkWidget *widget, FMPropertiesWindow *properties_
 						   GTK_WINDOW (properties_window),
 						   (EelIconSelectionFunction) set_icon_callback,
 						   properties_window);						   
+#endif
 }
 
 static void
