@@ -29,7 +29,6 @@
 #include <config.h>
 
 #include "nautilus-application.h"
-#include "nautilus-services.h"
 #include "nautilus-window-manage-views.h"
 #include "nautilus-window-private.h"
 #include "nautilus-window.h"
@@ -43,14 +42,13 @@
 #include <gtk/gtkframe.h>
 #include <gtk/gtktogglebutton.h>
 #include <libgnome/gnome-i18n.h>
-#include <libgnomeui/gnome-preferences.h>
 #include <libnautilus-private/nautilus-bonobo-extensions.h>
 #include <libnautilus-private/nautilus-bookmark.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-theme.h>
 
-/* FIXME bugzilla.eazel.com 1243: 
+/* FIXME bugzilla.gnome.org 41243: 
  * We should use inheritance instead of these special cases
  * for the desktop window.
  */
@@ -104,7 +102,9 @@ create_back_or_forward_menu (NautilusWindow *window, gboolean back)
   		gtk_signal_connect
 			(GTK_OBJECT(menu_item), 
 			 "activate",
-			 back ? activate_back_menu_item_callback : activate_forward_menu_item_callback, 
+			 back
+			 ? G_CALLBACK (activate_back_menu_item_callback)
+			 : G_CALLBACK (activate_forward_menu_item_callback),
 			 window);
 		
 		gtk_menu_append (menu, menu_item);
@@ -250,7 +250,11 @@ get_pixbuf_for_xml_node (NautilusWindow *window, const char *node_path)
 	GdkPixbuf *pixbuf;
 
 	node = bonobo_ui_component_get_tree (window->details->shell_ui, node_path, FALSE, NULL);
+#if GNOME2_CONVERSION_COMPLETE
 	pixbuf = bonobo_ui_util_xml_get_icon_pixbuf (node, FALSE);
+#else
+	pixbuf = NULL;
+#endif
 	bonobo_ui_node_free (node);
 
 	return pixbuf;
@@ -273,16 +277,17 @@ set_up_special_bonobo_button (NautilusWindow *window,
 	if (icon_file_name == NULL) {
 		pixbuf = get_pixbuf_for_xml_node (window, control_path);
 	} else {
-		pixbuf = gdk_pixbuf_new_from_file (icon_file_name);
+		pixbuf = gdk_pixbuf_new_from_file (icon_file_name, NULL);
 		g_free (icon_file_name);
 	}
 	
 	nautilus_window_ui_freeze (window);
 
-	bonobo_ui_toolbar_button_item_set_icon (item, pixbuf);
-	gdk_pixbuf_unref (pixbuf);
+	bonobo_ui_toolbar_button_item_set_image (item, gtk_image_new_from_pixbuf (pixbuf));
+	g_object_unref (pixbuf);
 
-	/* FIXME bugzilla.eazel.com 5005:
+#if GNOME2_CONVERSION_COMPLETE
+	/* FIXME bugzilla.gnome.org 45005:
 	 * Setting the style here accounts for the preference, but does not
 	 * account for a hard-wired toolbar style or later changes in style
 	 * (such as if the toolbar is detached and made vertical). There
@@ -293,6 +298,7 @@ set_up_special_bonobo_button (NautilusWindow *window,
 		 gnome_preferences_get_toolbar_labels ()
 		 	? BONOBO_UI_TOOLBAR_ITEM_STYLE_ICON_AND_TEXT_VERTICAL
 		 	: BONOBO_UI_TOOLBAR_ITEM_STYLE_ICON_ONLY);
+#endif
 
 	nautilus_window_ui_thaw (window);
 }			      
@@ -315,12 +321,6 @@ set_up_toolbar_images (NautilusWindow *window)
 	set_up_standard_bonobo_button (window, "/Toolbar/Go to Web Search", "SearchWeb", TRUE);
 	set_up_standard_bonobo_button (window, "/Toolbar/Stop", "Stop", FALSE);
 
-	/* Set up the services toolbar button if needed */
-	if (nautilus_services_are_enabled ()) {
-		set_up_standard_bonobo_button (window, "/Toolbar/Extra Buttons Placeholder/Services",
-					       "Services", TRUE);
-	}
-
 	bonobo_ui_component_thaw (window->details->shell_ui, NULL);
 
 	nautilus_window_ui_thaw (window);
@@ -372,13 +372,13 @@ set_up_back_or_forward_toolbar_item (NautilusWindow *window,
 	gtk_widget_show (GTK_WIDGET (item));
 
 	button = bonobo_ui_toolbar_button_item_get_button_widget (item);
-	gtk_signal_connect (GTK_OBJECT (button),
+	g_signal_connect (button,
 			    "button_press_event",
-			    GTK_SIGNAL_FUNC (back_or_forward_button_pressed_callback),
+			    G_CALLBACK (back_or_forward_button_pressed_callback),
 			    window);
-	gtk_signal_connect (GTK_OBJECT (button),
+	g_signal_connect (button,
 			    "clicked",
-			    GTK_SIGNAL_FUNC (back_or_forward_button_clicked_callback),
+			    G_CALLBACK (back_or_forward_button_clicked_callback),
 			    window);
 	set_widget_for_bonobo_control (window, GTK_WIDGET (item), control_path);
 
@@ -394,7 +394,7 @@ nautilus_window_initialize_toolbars (NautilusWindow *window)
 
 	CORBA_exception_init (&ev);
 
-	/* FIXME bugzilla.eazel.com 1243: 
+	/* FIXME bugzilla.gnome.org 41243: 
 	 * We should use inheritance instead of these special cases
 	 * for the desktop window.
 	 */
