@@ -28,7 +28,6 @@
 #include <config.h>
 #include "nautilus-zoom-control.h"
 
-#include <libgnome/gnome-defs.h>
 
 #include <math.h>
 #include <gnome.h>
@@ -38,7 +37,6 @@
 #include <gtk/gtkmenu.h>
 #include <gtk/gtkmenuitem.h>
 #include <libgnome/gnome-util.h>
-#include <libgnomeui/gnome-pixmap.h>
 #include <eel/eel-graphic-effects.h>
 #include <eel/eel-gtk-macros.h>
 #include <eel/eel-gtk-extensions.h>
@@ -46,6 +44,7 @@
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-icon-factory.h>
 #include <libnautilus-private/nautilus-file-utilities.h>
+#include <libnautilus-private/nautilus-marshal.h>
 #include <libnautilus-private/nautilus-theme.h>
 
 enum {
@@ -88,90 +87,29 @@ struct NautilusZoomControlDetails {
 
 static guint signals[LAST_SIGNAL];
 
-static void     nautilus_zoom_control_initialize_class 	 (NautilusZoomControlClass *klass);
-static void     nautilus_zoom_control_initialize       	 (NautilusZoomControl *zoom_control);
-static void	nautilus_zoom_control_destroy		 (GtkObject *object);
-static void     nautilus_zoom_control_draw 	       	 (GtkWidget *widget, 
-							  GdkRectangle *box);
-static int	nautilus_zoom_control_expose 		 (GtkWidget *widget, 
-							  GdkEventExpose *event);
-static 		gboolean nautilus_zoom_control_button_press_event (GtkWidget *widget, 
-							  GdkEventButton *event);
-static int	nautilus_zoom_control_leave_notify	 (GtkWidget        *widget,
-			 				  GdkEventCrossing *event);
-static gboolean nautilus_zoom_control_motion_notify       (GtkWidget        *widget,
-						     	  GdkEventMotion   *event);
-
-static void	nautilus_zoom_control_load_images	 (NautilusZoomControl *zoom_control);
-static void	nautilus_zoom_control_unload_images	 (NautilusZoomControl *zoom_control);
-static void	nautilus_zoom_control_theme_changed 	 (gpointer user_data);
-static void	nautilus_zoom_control_size_allocate	 (GtkWidget *widget, GtkAllocation *allocation);
-static void	nautilus_zoom_control_set_prelight_mode	 (NautilusZoomControl *zoom_control, PrelightMode mode);
-
-
-void            draw_number		                 (GtkWidget *widget, 
-							  GdkRectangle *box);
+static void nautilus_zoom_control_class_init    (NautilusZoomControlClass *klass);
+static void nautilus_zoom_control_init          (NautilusZoomControl      *zoom_control);
+static void nautilus_zoom_control_load_images   (NautilusZoomControl      *zoom_control);
+static void nautilus_zoom_control_unload_images (NautilusZoomControl      *zoom_control);
+static void nautilus_zoom_control_theme_changed (gpointer                  user_data);
+void        draw_number                         (GtkWidget                *widget,
+						 GdkRectangle             *box);
 
 /* button assignments */
 #define CONTEXTUAL_MENU_BUTTON 3
 
-EEL_DEFINE_CLASS_BOILERPLATE (NautilusZoomControl, nautilus_zoom_control, GTK_TYPE_EVENT_BOX)
+EEL_CLASS_BOILERPLATE (NautilusZoomControl, nautilus_zoom_control, GTK_TYPE_EVENT_BOX)
 
 static void
-nautilus_zoom_control_initialize_class (NautilusZoomControlClass *zoom_control_class)
+nautilus_zoom_control_finalize (GObject *object)
 {
-	GtkObjectClass *object_class = GTK_OBJECT_CLASS (zoom_control_class);
-	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (zoom_control_class);
-	
-	object_class->destroy = nautilus_zoom_control_destroy;
+	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_THEME,
+					 nautilus_zoom_control_theme_changed,
+					 object);
 
-	widget_class->draw = nautilus_zoom_control_draw;
-	widget_class->expose_event = nautilus_zoom_control_expose;
-	widget_class->button_press_event = nautilus_zoom_control_button_press_event;
-  	widget_class->leave_notify_event = nautilus_zoom_control_leave_notify;
-	widget_class->motion_notify_event = nautilus_zoom_control_motion_notify;
+	g_free (NAUTILUS_ZOOM_CONTROL (object)->details);
 
-	widget_class->size_allocate = nautilus_zoom_control_size_allocate;
-	
-	signals[ZOOM_IN] =
-		gtk_signal_new ("zoom_in",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusZoomControlClass, 
-						   zoom_in),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
-
-	signals[ZOOM_OUT] =
-		gtk_signal_new ("zoom_out",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusZoomControlClass, 
-						   zoom_out),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
-
-	signals[ZOOM_TO_LEVEL] =
-		gtk_signal_new ("zoom_to_level",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusZoomControlClass, 
-						   zoom_to_level),
-				eel_gtk_marshal_NONE__DOUBLE,
-				GTK_TYPE_NONE,
-				1,
-				GTK_TYPE_DOUBLE);
-
-	signals[ZOOM_TO_FIT] =
-		gtk_signal_new ("zoom_to_fit",
-				GTK_RUN_LAST,
-				object_class->type,
-				GTK_SIGNAL_OFFSET (NautilusZoomControlClass, 
-						   zoom_to_fit),
-				gtk_marshal_NONE__NONE,
-				GTK_TYPE_NONE, 0);
-
-	gtk_object_class_add_signals (object_class, signals, LAST_SIGNAL);
+	EEL_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
 }
 
 static void 
@@ -183,12 +121,6 @@ nautilus_zoom_control_destroy (GtkObject *object)
 	/* deallocate pixbufs */
 	nautilus_zoom_control_unload_images (NAUTILUS_ZOOM_CONTROL (object));
 
-	eel_preferences_remove_callback (NAUTILUS_PREFERENCES_THEME,
-					      nautilus_zoom_control_theme_changed,
-					      object);
-
-	g_free (NAUTILUS_ZOOM_CONTROL (object)->details);
-	
 	EEL_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
 }
 
@@ -205,7 +137,7 @@ get_zoom_width (NautilusZoomControl *zoom_control)
 }
 
 static void
-nautilus_zoom_control_initialize (NautilusZoomControl *zoom_control)
+nautilus_zoom_control_init (NautilusZoomControl *zoom_control)
 {
 	GtkWidget *widget = GTK_WIDGET (zoom_control);
 	int	  zoom_width;
@@ -335,7 +267,7 @@ void draw_number (GtkWidget *widget, GdkRectangle *box)
 	}
 	
 	if (number_pixbuf != zoom_control->details->number_strip) {
-		gdk_pixbuf_unref (number_pixbuf);
+		g_object_unref (number_pixbuf);
 	}
 	
 	gdk_gc_unref(temp_gc);
@@ -362,7 +294,7 @@ draw_pixbuf_with_prelight (NautilusZoomControl *zoom_control, GdkPixbuf *pixbuf,
 	}
 	draw_pixbuf (temp_pixbuf, GTK_WIDGET (zoom_control)->window, x_pos, y_pos + zoom_control->details->y_offset);
 	if (pixbuf != temp_pixbuf) {
-		gdk_pixbuf_unref (temp_pixbuf);
+		g_object_unref (temp_pixbuf);
 	}
 
 }
@@ -417,22 +349,6 @@ draw_zoom_control_image (GtkWidget *widget, GdkRectangle *box)
 	}
 }
 
-static void
-nautilus_zoom_control_draw (GtkWidget *widget, GdkRectangle *box)
-{
-	g_return_if_fail (widget != NULL);
-	g_return_if_fail (NAUTILUS_IS_ZOOM_CONTROL (widget));
-
-	/* Clear the widget get the default widget background before drawing our stuff */
-	gdk_window_clear_area (widget->window,
-			       0,
-			       0,
-			       widget->allocation.width,
-			       widget->allocation.height);
-	draw_zoom_control_image (widget, box);	
-	draw_number (widget, box);
-}
-
 /* handle expose events */
 
 static int
@@ -471,19 +387,23 @@ static void
 nautilus_zoom_control_unload_images (NautilusZoomControl *zoom_control)
 {
 	if (zoom_control->details->zoom_body_image) {
-		gdk_pixbuf_unref (zoom_control->details->zoom_body_image);
+		g_object_unref (zoom_control->details->zoom_body_image);
+		zoom_control->details->zoom_body_image = NULL;
 	}
 	
 	if (zoom_control->details->zoom_decrement_image) {
-		gdk_pixbuf_unref (zoom_control->details->zoom_decrement_image);
+		g_object_unref (zoom_control->details->zoom_decrement_image);
+		zoom_control->details->zoom_decrement_image = NULL;
 	}
 	
 	if (zoom_control->details->zoom_increment_image) {
-		gdk_pixbuf_unref (zoom_control->details->zoom_increment_image);
+		g_object_unref (zoom_control->details->zoom_increment_image);
+		zoom_control->details->zoom_increment_image = NULL;
 	}
 
 	if (zoom_control->details->number_strip != NULL) {
-		gdk_pixbuf_unref (zoom_control->details->number_strip);
+		g_object_unref (zoom_control->details->number_strip);
+		zoom_control->details->number_strip = NULL;
 	}
 
 	if (zoom_control->details->label_font != NULL) {
@@ -501,7 +421,7 @@ load_themed_image (const char *file_name)
 	
 	image_path = nautilus_theme_get_image_path (file_name);
 	if (image_path) {
-		pixbuf = gdk_pixbuf_new_from_file (image_path);
+		pixbuf = gdk_pixbuf_new_from_file (image_path, NULL);
 		g_free (image_path);
 		return pixbuf;
 	}
@@ -550,7 +470,7 @@ zoom_menu_callback (GtkMenuItem *item, gpointer callback_data)
 		return;
 	}
 
-	zoom_level = * (double *) gtk_object_get_data (GTK_OBJECT (item), "zoom_level");
+	zoom_level = * (double *) g_object_get_data (G_OBJECT (item), "zoom_level");
 
 	/* Assume we can zoom and then check whether we're right. */
 	can_zoom = TRUE;
@@ -563,7 +483,7 @@ zoom_menu_callback (GtkMenuItem *item, gpointer callback_data)
 
 	/* if we can zoom */
 	if (can_zoom) {	
-		gtk_signal_emit (GTK_OBJECT (zoom_control), signals[ZOOM_TO_LEVEL], zoom_level);
+		g_signal_emit (zoom_control, signals[ZOOM_TO_LEVEL], 0, zoom_level);
 	}
 }
 
@@ -603,9 +523,9 @@ create_zoom_menu_item (GtkMenu *menu, GtkWidget *widget, float zoom_level,
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menu_item), 
 					zoom_level == zoom_control->details->zoom_level);
 	
-	gtk_object_set_data_full (GTK_OBJECT (menu_item), "zoom_level", zoom_level_ptr, g_free);
-	gtk_signal_connect (GTK_OBJECT (menu_item), "activate",
-			    GTK_SIGNAL_FUNC (zoom_menu_callback),
+	g_object_set_data_full (G_OBJECT (menu_item), "zoom_level", zoom_level_ptr, g_free);
+	g_signal_connect (menu_item, "activate",
+			    G_CALLBACK (zoom_menu_callback),
 			    zoom_control);
 
   	gtk_widget_show (menu_item);
@@ -655,11 +575,11 @@ nautilus_zoom_control_button_press_event (GtkWidget *widget, GdkEventButton *eve
  	}
 	
 	if ((event->x < (width / 3)) && nautilus_zoom_control_can_zoom_out (zoom_control)) {
-		gtk_signal_emit (GTK_OBJECT (widget), signals[ZOOM_OUT]);			
+		g_signal_emit (widget, signals[ZOOM_OUT], 0);			
 	} else if ((event->x > ((2 * width) / 3)) && nautilus_zoom_control_can_zoom_in (zoom_control)) {
-		gtk_signal_emit (GTK_OBJECT (widget), signals[ZOOM_IN]);			
+		g_signal_emit (widget, signals[ZOOM_IN], 0);			
 	} else if ((event->x >= (center - (width >> 3))) && (event->x <= (center + (width >> 3)))) {
-		gtk_signal_emit (GTK_OBJECT (widget), signals[ZOOM_TO_FIT]);			
+		g_signal_emit (widget, signals[ZOOM_TO_FIT], 0);			
 	}
 
 	/*
@@ -800,3 +720,64 @@ nautilus_zoom_control_can_zoom_out (NautilusZoomControl *zoom_control)
 		(zoom_control->details->zoom_level
 		 > zoom_control->details->min_zoom_level);
 }
+
+static void
+nautilus_zoom_control_class_init (NautilusZoomControlClass *zoom_control_class)
+{
+	GObjectClass *gobject_class = G_OBJECT_CLASS (zoom_control_class);
+	GtkObjectClass *object_class = GTK_OBJECT_CLASS (zoom_control_class);
+	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (zoom_control_class);
+	
+	gobject_class->finalize = nautilus_zoom_control_finalize;
+	
+	object_class->destroy = nautilus_zoom_control_destroy;
+
+	widget_class->expose_event = nautilus_zoom_control_expose;
+	widget_class->button_press_event = nautilus_zoom_control_button_press_event;
+  	widget_class->leave_notify_event = nautilus_zoom_control_leave_notify;
+	widget_class->motion_notify_event = nautilus_zoom_control_motion_notify;
+
+	widget_class->size_allocate = nautilus_zoom_control_size_allocate;
+	
+	signals[ZOOM_IN] =
+		g_signal_new ("zoom_in",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (NautilusZoomControlClass, 
+						   zoom_in),
+		              NULL, NULL,
+		              gtk_marshal_VOID__VOID,
+		              G_TYPE_NONE, 0);
+
+	signals[ZOOM_OUT] =
+		g_signal_new ("zoom_out",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (NautilusZoomControlClass, 
+						   zoom_out),
+		              NULL, NULL,
+		              gtk_marshal_VOID__VOID,
+		              G_TYPE_NONE, 0);
+
+	signals[ZOOM_TO_LEVEL] =
+		g_signal_new ("zoom_to_level",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (NautilusZoomControlClass, 
+						   zoom_to_level),
+		              NULL, NULL,
+		              nautilus_marshal_VOID__DOUBLE,
+		              G_TYPE_NONE,
+			      1,
+			      G_TYPE_DOUBLE);
+
+	signals[ZOOM_TO_FIT] =
+		g_signal_new ("zoom_to_fit",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (NautilusZoomControlClass, 
+						   zoom_to_fit),
+		              NULL, NULL,
+		              gtk_marshal_VOID__VOID,
+		              G_TYPE_NONE, 0);
+}
