@@ -11,20 +11,7 @@ test_init (int *argc,
 	gdk_rgb_init ();
 	gnome_vfs_init ();
 
-	eel_make_warnings_and_criticals_stop_in_debugger
-		(G_LOG_DOMAIN, g_log_domain_glib,
-		 "Bonobo",
-		 "Gdk",
-		 "GnomeUI",
-		 "GnomeVFS",
-		 "GnomeVFS-CORBA",
-		 "GnomeVFS-pthread",
-		 "Gtk",
-		 "Nautilus",
-		 "Nautilus-Authenticate",
-		 "Nautilus-Tree",
-		 "ORBit",
-		 NULL);
+	eel_make_warnings_and_criticals_stop_in_debugger ();
 }
 
 int
@@ -58,12 +45,11 @@ test_window_new (const char *title, guint border_width)
 		gtk_window_set_title (GTK_WINDOW (window), title);
 	}
 
-	gtk_signal_connect (GTK_OBJECT (window),
-			    "delete_event",
-			    GTK_SIGNAL_FUNC (test_delete_event),
-			    NULL);
+	g_signal_connect (window,
+                          "delete_event",
+                          G_CALLBACK (test_delete_event),
+                          NULL);
 	
-	gtk_window_set_policy (GTK_WINDOW (window), TRUE, TRUE, FALSE);
 	gtk_container_set_border_width (GTK_CONTAINER (window), border_width);
 	
 	return window;
@@ -117,7 +103,7 @@ test_pixbuf_new_named (const char *name, float scale)
 		path = g_strdup_printf ("%s/%s", NAUTILUS_DATADIR, name);
 	}
 
-	pixbuf = gdk_pixbuf_new_from_file (path);
+	pixbuf = gdk_pixbuf_new_from_file (path, NULL);
 
 	g_free (path);
 
@@ -130,7 +116,7 @@ test_pixbuf_new_named (const char *name, float scale)
 
 		scaled = gdk_pixbuf_scale_simple (pixbuf, width, height, GDK_INTERP_BILINEAR);
 
-		gdk_pixbuf_unref (pixbuf);
+		g_object_unref (pixbuf);
 
 		g_return_val_if_fail (scaled != NULL, NULL);
 
@@ -142,7 +128,6 @@ test_pixbuf_new_named (const char *name, float scale)
 
 GtkWidget *
 test_image_new (const char *pixbuf_name,
-		const char *tile_name,
 		float scale,
 		gboolean with_background)
 {
@@ -161,18 +146,7 @@ test_image_new (const char *pixbuf_name,
 
 		if (pixbuf != NULL) {
 			eel_image_set_pixbuf (EEL_IMAGE (image), pixbuf);
-			gdk_pixbuf_unref (pixbuf);
-		}
-	}
-
-	if (tile_name != NULL) {
-		GdkPixbuf *tile_pixbuf;
-
-		tile_pixbuf = test_pixbuf_new_named (tile_name, 1.0);
-
-		if (tile_pixbuf != NULL) {
-			eel_image_set_tile_pixbuf (EEL_IMAGE (image), tile_pixbuf);
-			gdk_pixbuf_unref (tile_pixbuf);
+			g_object_unref (pixbuf);
 		}
 	}
 
@@ -181,7 +155,6 @@ test_image_new (const char *pixbuf_name,
 
 GtkWidget *
 test_label_new (const char *text,
-		const char *tile_name,
 		gboolean with_background,
 		int num_sizes_larger)
 {
@@ -191,28 +164,7 @@ test_label_new (const char *text,
 		text = "Foo";
 	}
 	
-	if (with_background) {
-		label = eel_label_new_with_background (text);
-	} else {
-		label = eel_label_new (text);
-	}
-
-	if (num_sizes_larger < 0) {
-		eel_label_make_smaller (EEL_LABEL (label), ABS (num_sizes_larger));
-	} else if (num_sizes_larger > 0) {
-		eel_label_make_larger (EEL_LABEL (label), num_sizes_larger);
-	}
-
-	if (tile_name != NULL) {
-		GdkPixbuf *tile_pixbuf;
-
-		tile_pixbuf = test_pixbuf_new_named (tile_name, 1.0);
-
-		if (tile_pixbuf != NULL) {
-			eel_label_set_tile_pixbuf (EEL_LABEL (label), tile_pixbuf);
-			gdk_pixbuf_unref (tile_pixbuf);
-		}
-	}
+	label = gtk_label_new (text);
 
 	return label;
 }
@@ -298,7 +250,9 @@ test_text_caption_get_text_as_int (const EelTextCaption *text_caption)
 
 	text = eel_text_caption_get_text (text_caption);
 
-	eel_eat_str_to_int (text, &result);
+	eel_str_to_int (text, &result);
+
+	g_free (text);
 
 	return result;
 }
@@ -311,7 +265,7 @@ test_window_set_title_with_pid (GtkWindow *window,
 	
 	g_return_if_fail (GTK_IS_WINDOW (window));
 
-	tmp = g_strdup_printf ("%d: %s", getpid (), title);
+	tmp = g_strdup_printf ("%lu: %s", (gulong) getpid (), title);
 	gtk_window_set_title (GTK_WINDOW (window), tmp);
 	g_free (tmp);
 }
@@ -363,5 +317,5 @@ test_pixbuf_draw_rectangle_tiled (GdkPixbuf *pixbuf,
 					     opacity,
 					     GDK_INTERP_NEAREST);
 
-	gdk_pixbuf_unref (tile_pixbuf);
+	g_object_unref (tile_pixbuf);
 }
